[Xfce4-commits] Port the remains to ThunarDevice.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to 3f1ca47ed23696aa6fe6a3e5d4c1caed45434977 (commit)
   from ee0ec148bfe77db34dfee59909a8fd08d62d29bd (commit)

commit 3f1ca47ed23696aa6fe6a3e5d4c1caed45434977
Author: Nick Schermer 
Date:   Sun Oct 7 02:07:50 2012 +0200

Port the remains to ThunarDevice.

 thunar/thunar-browser.c|  120 
 thunar/thunar-browser.h|   11 ++--
 thunar/thunar-device-monitor.c |   80 +++-
 thunar/thunar-gio-extensions.c |  132 
 thunar/thunar-gio-extensions.h |3 -
 thunar/thunar-launcher.c   |  126 +-
 thunar/thunar-shortcuts-view.c |   57 +-
 thunar/thunar-tree-model.c |   33 --
 thunar/thunar-window.c |   33 +-
 9 files changed, 237 insertions(+), 358 deletions(-)

diff --git a/thunar/thunar-browser.c b/thunar/thunar-browser.c
index cd0c29d..a608518 100644
--- a/thunar/thunar-browser.c
+++ b/thunar/thunar-browser.c
@@ -32,7 +32,7 @@
 
 
 typedef struct _PokeFileData   PokeFileData;
-typedef struct _PokeVolumeData PokeVolumeData;
+typedef struct _PokeDeviceData PokeDeviceData;
 
 
 
@@ -58,12 +58,12 @@ struct _PokeFileData
   gpointer  user_data;
 };
 
-struct _PokeVolumeData
+struct _PokeDeviceData
 {
   ThunarBrowser  *browser;
-  GVolume*volume;
+  ThunarDevice   *device;
   ThunarFile *mount_point;
-  ThunarBrowserPokeVolumeFunc func;
+  ThunarBrowserPokeDeviceFunc func;
   gpointeruser_data;
 };
 
@@ -150,20 +150,20 @@ thunar_browser_poke_file_data_free (PokeFileData 
*poke_data)
 
 
 
-static PokeVolumeData *
-thunar_browser_poke_volume_data_new (ThunarBrowser  *browser,
- GVolume*volume,
- ThunarBrowserPokeVolumeFunc func,
+static PokeDeviceData *
+thunar_browser_poke_device_data_new (ThunarBrowser  *browser,
+ ThunarDevice   *device,
+ ThunarBrowserPokeDeviceFunc func,
  gpointeruser_data)
 {
-  PokeVolumeData *poke_data;
+  PokeDeviceData *poke_data;
 
   _thunar_return_val_if_fail (THUNAR_IS_BROWSER (browser), NULL);
-  _thunar_return_val_if_fail (G_IS_VOLUME (volume), NULL);
+  _thunar_return_val_if_fail (THUNAR_IS_DEVICE (device), NULL);
 
-  poke_data = g_slice_new0 (PokeVolumeData);
+  poke_data = g_slice_new0 (PokeDeviceData);
   poke_data->browser = g_object_ref (browser);
-  poke_data->volume = g_object_ref (volume);
+  poke_data->device = g_object_ref (device);
   poke_data->func = func;
   poke_data->user_data = user_data;
 
@@ -173,16 +173,16 @@ thunar_browser_poke_volume_data_new (ThunarBrowser
  *browser,
 
 
 static void
-thunar_browser_poke_volume_data_free (PokeVolumeData *poke_data)
+thunar_browser_poke_device_data_free (PokeDeviceData *poke_data)
 {
   _thunar_return_if_fail (poke_data != NULL);
   _thunar_return_if_fail (THUNAR_IS_BROWSER (poke_data->browser));
-  _thunar_return_if_fail (G_IS_VOLUME (poke_data->volume));
+  _thunar_return_if_fail (THUNAR_IS_DEVICE (poke_data->device));
 
   g_object_unref (poke_data->browser);
-  g_object_unref (poke_data->volume);
+  g_object_unref (poke_data->device);
 
-  g_slice_free (PokeVolumeData, poke_data);
+  g_slice_free (PokeDeviceData, poke_data);
 }
 
 
@@ -549,137 +549,123 @@ thunar_browser_poke_file (ThunarBrowser
*browser,
 
 
 static void
-thunar_browser_poke_volume_file_finish (GFile  *location,
+thunar_browser_poke_device_file_finish (GFile  *location,
 ThunarFile *file,
 GError *error,
 gpointeruser_data)
 {
-  PokeVolumeData *poke_data = user_data;
+  PokeDeviceData *poke_data = user_data;
 
   _thunar_return_if_fail (G_IS_FILE (location));
   _thunar_return_if_fail (user_data != NULL);
   _thunar_return_if_fail (THUNAR_IS_BROWSER (poke_data->browser));
-  _thunar_return_if_fail (G_IS_VOLUME (poke_data->volume));
+  _thunar_return_if_fail (THUNAR_IS_DEVICE (poke_data->device));
 
   if (poke_data->func != NULL)
 {
-  (poke_data->func) (poke_data->browser, poke_data->volume, file, error,
+  (poke_data->func) (poke_data->browser, poke_data->device, file, error,
  poke_data->user_data);
 }
 
-  thunar_browser_poke_volume_data_free (poke_data);
+  thunar_browser_poke_device_data_free (poke_data);
 }
 
 
 
 static void
-thunar_browser_poke_volume_finish (GObject  *object,
-   GAsyncResult *result,
+thunar_browser_poke_device_finish (ThunarDevice *device,
+   const GErro

[Xfce4-commits] Port the shortcuts pane to ThunarDevice.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to 083417bba6399a44bbb5b5bcabaa3b9721fe2fbe (commit)
   from a0f743d61115cf90a48d6273f9b569e2b7dad63f (commit)

commit 083417bba6399a44bbb5b5bcabaa3b9721fe2fbe
Author: Nick Schermer 
Date:   Sun Oct 7 00:14:12 2012 +0200

Port the shortcuts pane to ThunarDevice.

 thunar/thunar-gio-extensions.c  |   37 ---
 thunar/thunar-gio-extensions.h  |2 -
 thunar/thunar-shortcuts-icon-renderer.c |   39 ++--
 thunar/thunar-shortcuts-model.c |  452 ---
 thunar/thunar-shortcuts-model.h |5 +-
 thunar/thunar-shortcuts-view.c  |  390 ++-
 6 files changed, 217 insertions(+), 708 deletions(-)

diff --git a/thunar/thunar-gio-extensions.c b/thunar/thunar-gio-extensions.c
index 288d936..ae52cda 100644
--- a/thunar/thunar-gio-extensions.c
+++ b/thunar/thunar-gio-extensions.c
@@ -578,43 +578,6 @@ thunar_g_volume_is_present (GVolume *volume)
 
 
 
-/**
- * thunar_g_volume_can_eject:
- *
- * If we should show the eject arrow/menu item
- * in the interface.
- *
- * Check if the mount can eject/unmount or else look at
- * the capability of the drive.
- **/
-gboolean
-thunar_g_volume_can_eject (GVolume *volume)
-{
-  GMount   *mount;
-  GDrive   *drive;
-  gboolean  can_eject;
-
-  mount = g_volume_get_mount (volume);
-  if (mount != NULL)
-{
-  can_eject = g_mount_can_eject (mount) || g_mount_can_unmount (mount);
-  g_object_unref (mount);
-  return can_eject;
-}
-
-  drive = g_volume_get_drive (volume);
-  if (drive != NULL)
-{
-  can_eject = g_drive_can_eject (drive);
-  g_object_unref (drive);
-  return can_eject;
-}
-
-  return FALSE;
-}
-
-
-
 gboolean
 thunar_g_app_info_launch (GAppInfo  *info,
   GFile *working_directory,
diff --git a/thunar/thunar-gio-extensions.h b/thunar/thunar-gio-extensions.h
index c7fde60..7afb1dd 100644
--- a/thunar/thunar-gio-extensions.h
+++ b/thunar/thunar-gio-extensions.h
@@ -72,8 +72,6 @@ void  thunar_g_file_list_free   (GList
 *list);
 gboolean  thunar_g_volume_is_removable  (GVolume   
*volume);
 gboolean  thunar_g_volume_is_mounted(GVolume   
*volume);
 gboolean  thunar_g_volume_is_present(GVolume   
*volume);
-gboolean
-thunar_g_volume_can_eject (GVolume *volume);
 
 gboolean  thunar_g_app_info_launch  (GAppInfo  *info,
  GFile 
*working_directory,
diff --git a/thunar/Makefile.am b/thunar/Makefile.am
index 3bafe9d..bc12573 100644
--- a/thunar/Makefile.am
+++ b/thunar/Makefile.am
@@ -71,6 +71,10 @@ thunar_SOURCES = 
\
thunar-details-view.h   \
thunar-dialogs.c\
thunar-dialogs.h\
+   thunar-device.c \
+   thunar-device.h \
+   thunar-device-monitor.c \
+   thunar-device-monitor.h \
thunar-dnd.c\
thunar-dnd.h\
thunar-emblem-chooser.c \
diff --git a/thunar/thunar-device-monitor.c b/thunar/thunar-device-monitor.c
new file mode 100644
index 000..c70ff7a
--- /dev/null
+++ b/thunar/thunar-device-monitor.c
@@ -0,0 +1,639 @@
+/*-
+ * Copyright (c) 2009-2010 Jannis Pohlmann 
+ * Copyright (c) 2012  Nick Schermer 
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
+ * Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
+#ifdef HAVE_CONFIG_H
+#include 
+#endif
+
+#include 
+#ifdef HAVE_GIO_UNIX
+#include 
+#endif
+
+#include 
+#include 
+
+
+
+/* signal identifiers */
+enum
+{
+  DEVICE_ADDED,
+  DEVICE_REMOVED,
+  DEVICE_CHANGED,
+  LAST_SIGNAL
+};
+
+
+
+static void   thunar_device_monitor_finalize   (GObject
*object);
+static void   thunar_device_monitor_volume_added   
(GVolumeMonitor *volume_monitor,
+GVolume
*volume,
+
ThunarDeviceMonitor*monitor);
+static void   thunar_device_monitor_volume_removed 
(GVolumeMonitor *volume_monitor,
+GVolume
*volume,
+
ThunarDeviceMonitor*monitor);
+static void   thunar_device_monitor_volume_changed 
(GVolumeMonitor *volume_monitor,
+GVolume
*volume,
+
ThunarDeviceMonitor*monitor);
+static void   thunar_device_monitor_mount_added
(GVolumeMonitor *volume_monitor,
+GMount 
*mount,
+
ThunarDeviceMonitor*monitor);
+static void   thunar_device_monitor_mount_removed  
(GVolumeMonitor *volume_monitor,
+GMount 
*moun

[Xfce4-commits] Only show eject icon on ejectable devices.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to e96bd793fbed41667d3fd8bbfc2ed231af71559d (commit)
   from 08df1859847a6284cee55a54e3dab3d5bda6d42e (commit)

commit e96bd793fbed41667d3fd8bbfc2ed231af71559d
Author: Nick Schermer 
Date:   Sat Oct 6 13:23:25 2012 +0200

Only show eject icon on ejectable devices.

 thunar/thunar-gio-extensions.c  |   37 +
 thunar/thunar-gio-extensions.h  |2 +
 thunar/thunar-shortcuts-model.c |   56 +-
 thunar/thunar-shortcuts-view.c  |2 +-
 4 files changed, 48 insertions(+), 49 deletions(-)

diff --git a/thunar/thunar-gio-extensions.c b/thunar/thunar-gio-extensions.c
index ae52cda..288d936 100644
--- a/thunar/thunar-gio-extensions.c
+++ b/thunar/thunar-gio-extensions.c
@@ -578,6 +578,43 @@ thunar_g_volume_is_present (GVolume *volume)
 
 
 
+/**
+ * thunar_g_volume_can_eject:
+ *
+ * If we should show the eject arrow/menu item
+ * in the interface.
+ *
+ * Check if the mount can eject/unmount or else look at
+ * the capability of the drive.
+ **/
+gboolean
+thunar_g_volume_can_eject (GVolume *volume)
+{
+  GMount   *mount;
+  GDrive   *drive;
+  gboolean  can_eject;
+
+  mount = g_volume_get_mount (volume);
+  if (mount != NULL)
+{
+  can_eject = g_mount_can_eject (mount) || g_mount_can_unmount (mount);
+  g_object_unref (mount);
+  return can_eject;
+}
+
+  drive = g_volume_get_drive (volume);
+  if (drive != NULL)
+{
+  can_eject = g_drive_can_eject (drive);
+  g_object_unref (drive);
+  return can_eject;
+}
+
+  return FALSE;
+}
+
+
+
 gboolean
 thunar_g_app_info_launch (GAppInfo  *info,
   GFile *working_directory,
diff --git a/thunar/thunar-gio-extensions.h b/thunar/thunar-gio-extensions.h
index 7afb1dd..c7fde60 100644
--- a/thunar/thunar-gio-extensions.h
+++ b/thunar/thunar-gio-extensions.h
@@ -72,6 +72,8 @@ void  thunar_g_file_list_free   (GList
 *list);
 gboolean  thunar_g_volume_is_removable  (GVolume   
*volume);
 gboolean  thunar_g_volume_is_mounted(GVolume   
*volume);
 gboolean  thunar_g_volume_is_present(GVolume   
*volume);
+gboolean
+thunar_g_volume_can_eject (GVolume *volume);
 
 gboolean  thunar_g_app_info_launch  (GAppInfo  *info,
  GFile 
*working_directory,
diff --git a/thunar/thunar-shortcuts-model.c b/thunar/thunar-shortcuts-model.c
index e16f2c9..79bd03d 100644
--- a/thunar/thunar-shortcuts-model.c
+++ b/thunar/thunar-shortcuts-model.c
@@ -557,9 +557,6 @@ thunar_shortcuts_model_get_value (GtkTreeModel *tree_model,
   GValue   *value)
 {
   ThunarShortcut *shortcut;
-  ThunarFile *file;
-  GMount *mount;
-  GFile  *mount_point;
   gbooleancan_eject;
 
   _thunar_return_if_fail (iter->stamp == THUNAR_SHORTCUTS_MODEL 
(tree_model)->stamp);
@@ -598,34 +595,7 @@ thunar_shortcuts_model_get_value (GtkTreeModel *tree_model,
 
 case THUNAR_SHORTCUTS_MODEL_COLUMN_FILE:
   g_value_init (value, THUNAR_TYPE_FILE);
-
-  if (shortcut->file != NULL)
-{
-  g_value_set_object (value, shortcut->file);
-}
-  if (shortcut->volume != NULL
-  || shortcut->mount != NULL)
-{
-  /* determine the mount of the volume */
-  if (shortcut->volume != NULL)
-mount = g_volume_get_mount (shortcut->volume);
-  else
-mount = g_object_ref (shortcut->mount);
-
-  if (G_LIKELY (mount != NULL))
-{
-  /* the volume is mounted, get the mount point */
-  mount_point = g_mount_get_root (mount);
-
-  /* try to allocate/reference a file pointing to the mount point 
*/
-  file = thunar_file_get (mount_point, NULL);
-  g_value_take_object (value, file);
-
-  /* release resources */
-  g_object_unref (mount_point);
-  g_object_unref (mount);
-}
-}
+  g_value_set_object (value, shortcut->file);
   break;
 
 case THUNAR_SHORTCUTS_MODEL_COLUMN_GICON:
@@ -658,19 +628,11 @@ thunar_shortcuts_model_get_value (GtkTreeModel 
*tree_model,
 
 case THUNAR_SHORTCUTS_MODEL_COLUMN_CAN_EJECT:
   if (shortcut->volume != NULL)
-{
-  can_eject = thunar_g_volume_is_removable (shortcut->volume)
-&& thunar_g_volume_is_present (shortcut->volume);
-}
+can_eject = thunar_g_volume_can_eject (shortcut->volume);
   else if (shortcut->mount != NULL)
-{
-  can_eject = g_mount_can_eject (shortcut->mount)
-  || g_mount_can_unmount (shortcut->mount);
-}
+can_eject = g_mount_can_eject (shortcut->mount) || g_mount_can_unmount 
(shortcut->mount);
   

[Xfce4-commits] Update translators, week 40.

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to f6d421e852a82b1ee66b334da91f04d53fce5a6c (commit)
   from de8a8c1da469a0ca620908010714b192572f0a0b (commit)

commit f6d421e852a82b1ee66b334da91f04d53fce5a6c
Author: Transifex 
Date:   Sun Oct 7 00:21:12 2012 +0200

Update translators, week 40.

 lib/translators.php |5 -
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/lib/translators.php b/lib/translators.php
index f9a97c4..10e7f0b 100644
--- a/lib/translators.php
+++ b/lib/translators.php
@@ -4,7 +4,7 @@
  * DO NOT EDIT IT MANUALLY!
  */
 
-$translators_stamp = "2012-09-30 00:21:06";
+$translators_stamp = "2012-10-07 00:21:12";
 
 $translators = array (
   'Amharic [am]' => array (
@@ -148,6 +148,7 @@ $translators = array (
 'anonxero' => 'anonxero'.ATSIGN.'linuxmail'.DOTSIGN.'org',
 'Mehdi Esmaeelpour' => 'ariarat'.ATSIGN.'gmail'.DOTSIGN.'com',
 'Ehsan Akhlaghi' => 'esnka'.ATSIGN.'yahoo'.DOTSIGN.'com',
+'mahmood mahm0ud' => 
'mahmud'.DOTSIGN.'tehrani'.ATSIGN.'gmail'.DOTSIGN.'com',
 'numb' => 'amir007ag'.ATSIGN.'gmail'.DOTSIGN.'com',
   ),
   'Finnish [fi]' => array (
@@ -292,12 +293,14 @@ $translators = array (
   ),
   'Polish [pl]' => array (
 'Piotr Sokół' => 'psokol'.ATSIGN.'jabster'.DOTSIGN.'pl',
+'Marcin Romańczuk' => 'abjsyn'.ATSIGN.'gmail'.DOTSIGN.'com',
 'Ewelina Drożańska' => 'blinqa'.ATSIGN.'gmail'.DOTSIGN.'com',
 'Paweł Drożański' => 'pawdro'.ATSIGN.'gmail'.DOTSIGN.'com',
 'Kamil Polczak' => 'elderlinx'.ATSIGN.'gmail'.DOTSIGN.'com',
 'Ireneusz Gierlach' => 
'irek'.DOTSIGN.'gierlach'.ATSIGN.'gmail'.DOTSIGN.'com',
 'jacek2v' => 'jacek2v'.ATSIGN.'gmail'.DOTSIGN.'com',
 'Jakub Waśko' => 'javazlaz'.ATSIGN.'gmail'.DOTSIGN.'com',
+'Michał Jeż' => 'michal'.DOTSIGN.'je2u'.ATSIGN.'gmail'.DOTSIGN.'com',
 'Kamil Konieczka' => 'klkkzm'.ATSIGN.'gmail'.DOTSIGN.'com',
 'kolofaza' => 'kolofaza'.ATSIGN.'o2'.DOTSIGN.'pl',
 'Michał Olber' => 'michal'.DOTSIGN.'olber'.ATSIGN.'osworld'.DOTSIGN.'pl',
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] Update translators, week 40.

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to d2b46f86dde38e8608bd9f3e9dac995f0be962ac (commit)
   from 4378f99e579bacbf7a3ad4e6dbcbefbc34f82051 (commit)

commit d2b46f86dde38e8608bd9f3e9dac995f0be962ac
Author: Transifex 
Date:   Sun Oct 7 00:21:03 2012 +0200

Update translators, week 40.

 xfce4-about/translators.h |5 -
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/xfce4-about/translators.h b/xfce4-about/translators.h
index 95733a4..b74d80f 100644
--- a/xfce4-about/translators.h
+++ b/xfce4-about/translators.h
@@ -24,7 +24,7 @@
 #include 
 #include 
 
-#define TRANSLATORS_H_STAMP "2012-09-30 00:21:02"
+#define TRANSLATORS_H_STAMP "2012-10-07 00:21:02"
 #define ATSIGN "@"
 #define DOTSIGN "."
 
@@ -240,6 +240,7 @@ static const TranslatorInfo xfce_translators_fa[] =
   { "anonxero", "anonxero" ATSIGN "linuxmail" DOTSIGN "org", FALSE },
   { "Mehdi Esmaeelpour", "ariarat" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { "Ehsan Akhlaghi", "esnka" ATSIGN "yahoo" DOTSIGN "com", FALSE },
+  { "mahmood mahm0ud", "mahmud" DOTSIGN "tehrani" ATSIGN "gmail" DOTSIGN 
"com", FALSE },
   { "numb", "amir007ag" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { NULL, NULL }
 };
@@ -462,12 +463,14 @@ static const TranslatorInfo xfce_translators_pa[] =
 static const TranslatorInfo xfce_translators_pl[] =
 {
   { "Piotr Sokół", "psokol" ATSIGN "jabster" DOTSIGN "pl", TRUE },
+  { "Marcin Romańczuk", "abjsyn" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { "Ewelina Drożańska", "blinqa" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { "Paweł Drożański", "pawdro" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { "Kamil Polczak", "elderlinx" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { "Ireneusz Gierlach", "irek" DOTSIGN "gierlach" ATSIGN "gmail" DOTSIGN 
"com", FALSE },
   { "jacek2v", "jacek2v" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { "Jakub Waśko", "javazlaz" ATSIGN "gmail" DOTSIGN "com", FALSE },
+  { "Michał Jeż", "michal" DOTSIGN "je2u" ATSIGN "gmail" DOTSIGN "com", FALSE 
},
   { "Kamil Konieczka", "klkkzm" ATSIGN "gmail" DOTSIGN "com", FALSE },
   { "kolofaza", "kolofaza" ATSIGN "o2" DOTSIGN "pl", FALSE },
   { "Michał Olber", "michal" DOTSIGN "olber" ATSIGN "osworld" DOTSIGN "pl", 
FALSE },
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Polish (pl) translation to 99%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 3df3b90844bf51ee25627bd092c613e30ff503fb (commit)
   from 51fc2758f2f4420f7de89342ed2b2a97b5a83fcf (commit)

commit 3df3b90844bf51ee25627bd092c613e30ff503fb
Author: Piotr Sokół 
Date:   Sun Oct 7 00:16:17 2012 +0200

l10n: Updated Polish (pl) translation to 99%

New status: 700 messages complete with 4 fuzzies and 2 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/pl.po |   10 +-
 1 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/po/pl.po b/po/pl.po
index 006ffac..9454e89 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -1250,12 +1250,12 @@ msgstr[1] "%d zaznaczone elementy (%s)"
 msgstr[2] "%d zaznaczonych elementów (%s)"
 
 #: ../thunar/thunar-list-model.c:2457
-#, fuzzy, c-format
+#, c-format
 msgid "%d folder selected"
 msgid_plural "%d folders selected"
-msgstr[0] "%d zaznaczony element"
-msgstr[1] "%d zaznaczone elementy"
-msgstr[2] "%d zaznaczonych elementów"
+msgstr[0] "%d zaznaczony katalog"
+msgstr[1] "%d zaznaczone katalogi"
+msgstr[2] "%d zaznaczonych katalogów"
 
 #. This is marked for translation in case a localizer
 #. * needs to change ", " to something else. The comma
@@ -1512,7 +1512,7 @@ msgstr "Poprawiać prawa katalogów automatycznie?"
 #: ../thunar/thunar-permissions-chooser.c:1133
 #, fuzzy
 msgid "Correct _folder permissions"
-msgstr "Poprawianie uprawnień katalogów"
+msgstr "Popraw uprawnienia do _katalogów"
 
 #: ../thunar/thunar-permissions-chooser.c:1135
 msgid ""
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Polish (pl) translation to 99%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 51fc2758f2f4420f7de89342ed2b2a97b5a83fcf (commit)
   from 41d556d4c4ab57430c74b6566dc2425641658db3 (commit)

commit 51fc2758f2f4420f7de89342ed2b2a97b5a83fcf
Author: Piotr Sokół 
Date:   Sun Oct 7 00:14:14 2012 +0200

l10n: Updated Polish (pl) translation to 99%

New status: 699 messages complete with 5 fuzzies and 2 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/pl.po |   35 +--
 1 files changed, 21 insertions(+), 14 deletions(-)

diff --git a/po/pl.po b/po/pl.po
index 96accd4..006ffac 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Thunar 1.2.1\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-10-06 16:24+\n"
+"POT-Creation-Date: 2012-10-06 21:45+\n"
 "PO-Revision-Date: 2012-04-19 20:23+0100\n"
 "Last-Translator: Michał Olber \n"
 "Language-Team: polski <>\n"
@@ -715,19 +715,22 @@ msgid "ReplaceDialogPart2|with the following file?"
 msgstr "następującym plikiem?"
 
 #: ../thunar/thunar-dialogs.c:760
-#, c-format
+#, c-format, fuzzy
 msgid ""
 "The desktop file \"%s\" is in an insecure location and not marked as "
 "executable. If you do not trust this program, click Cancel."
-msgstr "Plik pulpitu \"%s\" znajduje się w niezabezpieczonym położeniu oraz 
nie jest oznaczony jako wykonywalny. Jeśli program jest niezaufany kliknij 
Anuluj"
+msgstr ""
+"Plik pulpitu \"%s\" znajduje się w niezabezpieczonym położeniu oraz nie jest "
+"oznaczony jako wykonywalny. Jeśli program jest niezaufany kliknij Anuluj"
 
 #: ../thunar/thunar-dialogs.c:777
 msgid "_Launch Anyway"
 msgstr "_Uruchom mimo wszystko"
 
 #: ../thunar/thunar-dialogs.c:779
+#, fuzzy
 msgid "Mark _Executable"
-msgstr "Oznacz jako _Wykonywalny"
+msgstr "Oznacz jako _wykonywalny"
 
 #: ../thunar/thunar-dnd.c:72
 msgid "_Copy here"
@@ -826,9 +829,8 @@ msgstr "Nie udało się przetworzyć pliku aktywatora: %s"
 
 #. if the .desktop file is not secure, ask user what to do
 #: ../thunar/thunar-file.c:1116
-#, fuzzy
 msgid "Untrusted application launcher"
-msgstr "Nie wybrano programu."
+msgstr "Niezaufany aktywator programu"
 
 #: ../thunar/thunar-file.c:1141
 #, c-format
@@ -838,7 +840,7 @@ msgstr "Nie określono pola Exec"
 #. if the .desktop file is not secure, ask user what to do
 #: ../thunar/thunar-file.c:1150
 msgid "Untrusted link launcher"
-msgstr "Niezaufany odnośnik aktywatora"
+msgstr "Niezaufany aktywator odnośnika"
 
 #: ../thunar/thunar-file.c:1166
 #, c-format
@@ -847,7 +849,7 @@ msgstr "Nie określono pola URL"
 
 #: ../thunar/thunar-file.c:1171
 msgid "Invalid desktop file"
-msgstr "Nieprawidłowy plik .desktop"
+msgstr "Nieprawidłowy plik aktywatora"
 
 #. create the "back" action
 #: ../thunar/thunar-history.c:154
@@ -993,7 +995,9 @@ msgstr "Pominąć go?"
 msgid ""
 "There is not enough space on the destination. Try to remove files to make "
 "space."
-msgstr "Brak przestrzeni w miejscu docelowym. Spróbuj usunąć pliki aby uzyskać 
przestrzeń."
+msgstr ""
+"Brak przestrzeni w miejscu docelowym. Spróbuj usunąć pliki aby uzyskać "
+"przestrzeń."
 
 #. append the "Open" menu action
 #: ../thunar/thunar-launcher.c:168 ../thunar/thunar-launcher.c:810
@@ -1812,7 +1816,7 @@ msgstr "Typ:"
 
 #: ../thunar/thunar-properties-dialog.c:340
 msgid "_Open With:"
-msgstr "Otwórz za pomocą:"
+msgstr "_Otwieranie za pomocą:"
 
 #: ../thunar/thunar-properties-dialog.c:354
 msgid "Link Target:"
@@ -2325,12 +2329,15 @@ msgstr "_Pusty plik"
 msgid ""
 "Error while copying to \"%s\": %s more space is required to copy to the "
 "destination"
-msgstr "Błąd podczas kopiowania do \"%s\": %s wymagana jest większa przestrzeń 
aby skopiować do miejsca docelowego."
+msgstr ""
+"Błąd podczas kopiowania do \"%s\": %s wymagana jest większa przestrzeń aby "
+"skopiować do miejsca docelowego."
 
 #: ../thunar/thunar-transfer-job.c:744
 #, c-format
 msgid "Error while copying to \"%s\": The destination is read-only"
-msgstr "Błąd podczas kopiowania do \"%s\": Miejsce docelowe jest tylko do 
odczytu"
+msgstr ""
+"Błąd podczas kopiowania do \"%s\": Miejsce docelowe jest tylko do odczytu"
 
 #: ../thunar/thunar-transfer-job.c:787
 msgid "Collecting files..."
@@ -2678,11 +2685,11 @@ msgstr "Wyświetla pasek stanu"
 
 #: ../thunar/thunar-window.c:345
 msgid "_Menubar"
-msgstr "_Menu"
+msgstr "Pasek p_oleceń"
 
 #: ../thunar/thunar-window.c:345
 msgid "Change the visibility of this window's menubar"
-msgstr "Zmienia widoczność paska menu tego okna"
+msgstr "Zmienia widoczność paska poleceń bieżącego okna"
 
 #. * add view options
 #. 
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Greek (el) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/aria2-xml-rpc
 to 6e8b4c9725f3121208d916d6f54281a11cca8f56 (commit)
   from 33e9cbc014111f17880977c99ebcfa74b533f63a (commit)

commit 6e8b4c9725f3121208d916d6f54281a11cca8f56
Author: Georgios Stefanakis 
Date:   Sat Oct 6 21:55:28 2012 +0200

l10n: Updated Greek (el) translation to 100%

New status: 52 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |   11 +--
 1 files changed, 5 insertions(+), 6 deletions(-)

diff --git a/po/el.po b/po/el.po
index 8511218..1db8089 100644
--- a/po/el.po
+++ b/po/el.po
@@ -3,7 +3,7 @@
 # This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR , YEAR.
 # Efstathios Iosifidis , 2012.
-#
+# 
 msgid ""
 msgstr ""
 "Project-Id-Version: eatmonkey git version\n"
@@ -12,14 +12,14 @@ msgstr ""
 "PO-Revision-Date: 2012-08-17 01:48+0300\n"
 "Last-Translator: Efstathios Iosifidis \n"
 "Language-Team: Ελληνικά, Σύγχρονα \n"
-"Language: el\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bits\n"
+"Language: el\n"
 "Plural-Forms: nplurals=2; plural=(n!=1);\n"
 "X-Poedit-Language: Greek\n"
-"X-Poedit-Country: GREECE\n"
 "X-Poedit-SourceCharset: utf-8\n"
+"X-Poedit-Country: GREECE\n"
 
 #: ../eatmonkey.desktop.in.h:1
 msgid "Download Manager"
@@ -151,7 +151,7 @@ msgstr "Σύνδεση σε προσαρμοσένο διακομιστή"
 
 #: ../src/settings.ui.h:10
 msgid "Distributed Hash Table allows to use torrents without a working tracker"
-msgstr ""
+msgstr "Ο διαμερισμένος πίνακας αλγορίθμων αποτυπώματος σας επιτρέπουν να 
κάνετε χρήση αρχείων torrent χωρίς την χρήση ενώς σε λειτουργεία tracker "
 
 #: ../src/settings.ui.h:13
 msgid "Edit configuration"
@@ -159,7 +159,7 @@ msgstr "Επεξεργασία ρυθμίσεων"
 
 #: ../src/settings.ui.h:14
 msgid "Enable DHT (Distributed Hash Table)"
-msgstr ""
+msgstr "Ενεργοποίηση DHT (διαμερισμένος πίνακας αλγορίθμων αποτυπώματος)"
 
 #: ../src/settings.ui.h:15
 msgid "Enable PEX (Peer Exchange)"
@@ -236,7 +236,6 @@ msgstr "Όνομα χρήστη:"
 msgid "aria2 XML-RPC Server"
 msgstr "Διακομιστής aria2 XML-RPC"
 
-#, fuzzy
 #~ msgid "Simple download manager for Xfce"
 #~ msgstr "Ένας χαζός διαχειριστής μεταφορών για μαϊμούδες και καπουκίνων!"
 
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Polish (pl) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/xfce-4.10
 to e5c23f2292e44b17497b8f27d6b389efb59d0bbc (commit)
   from befc1ee0aedfee60182aacf429f4dea00176a8bb (commit)

commit e5c23f2292e44b17497b8f27d6b389efb59d0bbc
Author: Marcin Romańczuk 
Date:   Sat Oct 6 21:54:06 2012 +0200

l10n: Updated Polish (pl) translation to 100%

New status: 213 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/pl.po |   75 -
 1 files changed, 39 insertions(+), 36 deletions(-)

diff --git a/po/pl.po b/po/pl.po
index 74f100e..6da29ab 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -5,21 +5,20 @@
 # Piotr Maliński , 2006.
 # Szymon Kałasz , 2006.
 # Piotr Sokół , 2009, 2011, 2012.
-#
+# 
 msgid ""
 msgstr ""
 "Project-Id-Version: xfdesktop 4.8.1\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-04-08 09:51+\n"
+"POT-Creation-Date: 2012-10-06 14:45+\n"
 "PO-Revision-Date: 2012-04-09 13:56+0200\n"
 "Last-Translator: Piotr Sokół \n"
 "Language-Team: polski <>\n"
-"Language: \n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bits\n"
-"Plural-Forms: nplurals=3; plural=((n==1) ? 0 : ((n%10>=2 && n%10<=4 && (n"
-"%100<10 || n%100>=20)) ? 1 : 2));\n"
+"Language: \n"
+"Plural-Forms: nplurals=3; plural=((n==1) ? 0 : ((n%10>=2 && n%10<=4 && 
(n%100<10 || n%100>=20)) ? 1 : 2));\n"
 
 #: ../common/xfdesktop-common.c:96 ../common/xfdesktop-common.c:200
 #, c-format
@@ -58,7 +57,7 @@ msgstr "Nośniki wymienne"
 msgid "Cannot create backdrop list \"%s\""
 msgstr "Nie można utworzyć pliku listy obrazów „%s”"
 
-#: ../settings/main.c:489 ../settings/main.c:862
+#: ../settings/main.c:489 ../settings/main.c:875
 msgid "Backdrop List Error"
 msgstr "Błąd listy obrazów"
 
@@ -84,80 +83,80 @@ msgstr "Zastąpienie pliku spowoduje usunięcie jego 
dotychczasowej zawartość.
 msgid "Replace"
 msgstr "Zamień"
 
-#: ../settings/main.c:858
+#: ../settings/main.c:871
 #, c-format
 msgid "Failed to write backdrop list to \"%s\""
 msgstr "Nie udało się zapisać listy obrazów „%s”"
 
-#: ../settings/main.c:885
+#: ../settings/main.c:898
 msgid "Add Image File(s)"
 msgstr "Wybór pliku"
 
-#: ../settings/main.c:894
+#: ../settings/main.c:907
 msgid "Image files"
 msgstr "Pliki obrazów"
 
-#: ../settings/main.c:899
+#: ../settings/main.c:912
 msgid "All files"
 msgstr "Wszystkie pliki"
 
-#: ../settings/main.c:1356
+#: ../settings/main.c:1376
 #, c-format
 msgid "Screen %d, Monitor %d (%s)"
 msgstr "Ekran %d, monitor %d (%s)"
 
-#: ../settings/main.c:1360
+#: ../settings/main.c:1380
 #, c-format
 msgid "Screen %d, Monitor %d"
 msgstr "Ekran %d, monitor %d"
 
-#: ../settings/main.c:1363
+#: ../settings/main.c:1383
 #, c-format
 msgid "Screen %d"
 msgstr "Ekran %d"
 
-#: ../settings/main.c:1368
+#: ../settings/main.c:1388
 #, c-format
 msgid "Monitor %d (%s)"
 msgstr "Monitor %d (%s)"
 
-#: ../settings/main.c:1372
+#: ../settings/main.c:1392
 #, c-format
 msgid "Monitor %d"
 msgstr "Monitor %d"
 
-#: ../settings/main.c:1631
+#: ../settings/main.c:1651
 msgid "Settings manager socket"
 msgstr "Określa gniazdo menedżera ustawień"
 
-#: ../settings/main.c:1631
+#: ../settings/main.c:1651
 msgid "SOCKET ID"
 msgstr "ID_GNIAZDA"
 
-#: ../settings/main.c:1632
+#: ../settings/main.c:1652
 msgid "Version information"
 msgstr "Informacje o wersji"
 
-#: ../settings/main.c:1649
+#: ../settings/main.c:1669
 #, c-format
 msgid "Type '%s --help' for usage."
 msgstr "Proszę wprowadzić „%s --help”, aby wypisać komunikat pomocy."
 
-#: ../settings/main.c:1661
+#: ../settings/main.c:1681
 msgid "The Xfce development team. All rights reserved."
 msgstr ""
 "Zespół twórców środowiska graficznego Xfce. Wszystkie prawa zastrzeżone."
 
-#: ../settings/main.c:1662
+#: ../settings/main.c:1682
 #, c-format
 msgid "Please report bugs to <%s>."
 msgstr "Proszę zgłaszać błędy na adres <%s>."
 
-#: ../settings/main.c:1669
+#: ../settings/main.c:1689
 msgid "Desktop Settings"
 msgstr "Pulpit"
 
-#: ../settings/main.c:1671
+#: ../settings/main.c:1691
 msgid "Unable to contact settings server"
 msgstr "Nie można połączyć z serwerem ustawień"
 
@@ -712,7 +711,7 @@ msgid "_Open in New Window"
 msgstr "_Otwórz w nowym oknie"
 
 #: ../src/xfdesktop-file-icon-manager.c:1425
-#: ../src/xfdesktop-special-file-icon.c:501 ../src/xfdesktop-volume-icon.c:683
+#: ../src/xfdesktop-special-file-icon.c:505 ../src/xfdesktop-volume-icon.c:691
 msgid "_Open"
 msgstr "_Otwórz"
 
@@ -769,7 +768,7 @@ msgid "Desktop _Settings..."
 msgstr "P_referencje pulpitu..."
 
 #: ../src/xfdesktop-file-icon-manager.c:1744
-#: ../src/xfdesktop-volume-icon.c:731
+#: ../src/xfdesktop-volume-icon.c:739
 msgid "P_roperties..."
 msgstr "_Właściwości..."
 
@@ -946,7 +945,7 @@ msgstr "Wysuwanie nośnika"
 msgid "The device \"%s\" is being ejected. This may take some time"
 msgstr "Trwa wysuwanie nośnika „%s”. Może to potrwać dłuższy czas."
 
-#

[Xfce4-commits] l10n: Updated Greek (el) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 485d8316f48091b4f3030a9c2f5d5bdb4b6f2584 (commit)
   from dfd361f2361c6f874c8533546dc2443aa1a10e34 (commit)

commit 485d8316f48091b4f3030a9c2f5d5bdb4b6f2584
Author: Georgios Stefanakis 
Date:   Sat Oct 6 21:50:12 2012 +0200

l10n: Updated Greek (el) translation to 100%

New status: 185 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |   10 +++---
 1 files changed, 7 insertions(+), 3 deletions(-)

diff --git a/po/el.po b/po/el.po
index f3cc2c6..18e7239 100644
--- a/po/el.po
+++ b/po/el.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: parole\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-08-10 08:57+\n"
+"POT-Creation-Date: 2012-10-06 15:54+\n"
 "PO-Revision-Date: 2010-03-30 23:39+0200\n"
 "Last-Translator: George Vlahavas \n"
 "Language-Team: \n"
@@ -53,6 +53,7 @@ msgid "Empty"
 msgstr "Άδειο"
 
 #: ../data/interfaces/parole.ui.h:10 ../src/parole-disc.c:125
+#: ../src/parole-disc.c:385
 msgid "Insert Disc"
 msgstr "Εισάγετε δίσκο"
 
@@ -186,8 +187,8 @@ msgid "Enabled"
 msgstr "Ενεργό"
 
 #: ../data/interfaces/plugins.ui.h:4
-msgid "Media Player plugins"
-msgstr "Πρόσθετα εφαρμογής αναπαραγωγής πολυμέσων"
+msgid "Extend your media player"
+msgstr "Επέκταση του αναπαραγωγού πολυμέσων"
 
 #: ../data/interfaces/plugins.ui.h:5
 msgid "Parole Plugins"
@@ -814,6 +815,9 @@ msgstr ""
 msgid "Power Manager Plugin"
 msgstr "Πρόσθετο Διαχείρισης Ενέργειας"
 
+#~ msgid "Media Player plugins"
+#~ msgstr "Πρόσθετα εφαρμογής αναπαραγωγής πολυμέσων"
+
 #~ msgid "From ISO image"
 #~ msgstr "Από εικόνα ISO"
 
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Greek (el) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/xfce-4.10
 to 6c7975450299556f424be4819aed4676b4ee87ae (commit)
   from 99e8cfc0b71864c02bc508c395c0b64e24cd3d8a (commit)

commit 6c7975450299556f424be4819aed4676b4ee87ae
Author: Georgios Stefanakis 
Date:   Sat Oct 6 21:48:33 2012 +0200

l10n: Updated Greek (el) translation to 100%

New status: 235 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |  539 +++---
 1 files changed, 269 insertions(+), 270 deletions(-)

diff --git a/po/el.po b/po/el.po
index a7700a7..48f3076 100644
--- a/po/el.po
+++ b/po/el.po
@@ -1,24 +1,24 @@
 # Greek translation of xfwm4.
 # Copyright (C) 2002-2006 The Xfce development team.
 # This file is distributed under the same license as the xfwm4 package.
-#
+# 
 # Stavros Giannouris , 2005.
 # Stathis Kamperis , 2006.
 # Evaggelos Balaskas , 2009.
 # Efstathios Iosifidis , 2012.
-#
+# 
 msgid ""
 msgstr ""
 "Project-Id-Version: xfwm4 git version\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-04-09 18:54+0200\n"
+"POT-Creation-Date: 2012-10-06 15:09+\n"
 "PO-Revision-Date: 2012-04-09 19:24+0300\n"
 "Last-Translator: Efstathios Iosifidis \n"
 "Language-Team: Ελληνικά, Σύγχρονα \n"
-"Language: \n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
+"Language: \n"
 "Plural-Forms: nplurals=2; plural=(n!=1);\n"
 "X-Poedit-Language: Greek\n"
 "X-Poedit-SourceCharset: utf-8\n"
@@ -91,237 +91,237 @@ msgid "Settings manager socket"
 msgstr "Υποδοχή διαχειριστή ρυθμίσεων"
 
 #: ../settings-dialogs/xfce-wm-settings.desktop.in.h:1
-#: ../settings-dialogs/xfwm4-dialog.glade.h:1
-msgid "Window Manager"
-msgstr "Διαχειριστής παραθύρων"
-
-#: ../settings-dialogs/xfce-wm-settings.desktop.in.h:2
-#: ../settings-dialogs/xfwm4-dialog.glade.h:2
+#: ../settings-dialogs/xfwm4-dialog.glade.h:29
 msgid "Configure window behavior and shortcuts"
 msgstr "Ρύθμιση συμπεριφοράς παραθύρων και συντομεύσεων"
 
-#: ../settings-dialogs/xfce-wmtweaks-settings.desktop.in.h:1
-#: ../settings-dialogs/xfwm4-tweaks-dialog.glade.h:1
-msgid "Window Manager Tweaks"
-msgstr "Προσαρμογή διαχειριστή παραθύρων"
+#: ../settings-dialogs/xfce-wm-settings.desktop.in.h:2
+#: ../settings-dialogs/xfwm4-dialog.glade.h:48
+msgid "Window Manager"
+msgstr "Διαχειριστής παραθύρων"
 
-#: ../settings-dialogs/xfce-wmtweaks-settings.desktop.in.h:2
-#: ../settings-dialogs/xfwm4-tweaks-dialog.glade.h:2
+#: ../settings-dialogs/xfce-wmtweaks-settings.desktop.in.h:1
+#: ../settings-dialogs/xfwm4-tweaks-dialog.glade.h:16
 msgid "Fine-tune window behaviour and effects"
 msgstr "Ρύθμιση συμπεριφοράς παραθύρων και φαινόμενων"
 
+#: ../settings-dialogs/xfce-wmtweaks-settings.desktop.in.h:2
+#: ../settings-dialogs/xfwm4-tweaks-dialog.glade.h:36
+msgid "Window Manager Tweaks"
+msgstr "Προσαρμογή διαχειριστή παραθύρων"
+
 #: ../settings-dialogs/xfce-workspaces-settings.desktop.in.h:1
 #: ../settings-dialogs/xfwm4-workspace-dialog.glade.h:1
+msgid "Configure layout, names and margins"
+msgstr "Ρύθμιση διάταξης, ονόματα και περιθώρια"
+
+#: ../settings-dialogs/xfce-workspaces-settings.desktop.in.h:2
+#: ../settings-dialogs/xfwm4-workspace-dialog.glade.h:5
 msgid "Workspaces"
 msgstr "Χώροι εργασίας"
 
-#: ../settings-dialogs/xfce-workspaces-settings.desktop.in.h:2
-#: ../settings-dialogs/xfwm4-workspace-dialog.glade.h:2
-msgid "Configure layout, names and margins"
-msgstr "Ρύθμιση διάταξης, ονόματα και περιθώρια"
+#: ../settings-dialogs/xfwm4-dialog.glade.h:1
+msgid "Box move and resize"
+msgstr "Συμπαγής μετακίνηση και αλλαγή μεγέθους"
+
+#: ../settings-dialogs/xfwm4-dialog.glade.h:2
+msgid "Button layout"
+msgstr "Διάταξη κουμπιών"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.h:3
-msgid "_Theme"
-msgstr "_Θέμα"
+msgid "Double click _action"
+msgstr "Εν_έργεια διπλού κλικ"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.h:4
-msgid "Title fon_t"
-msgstr "Γρ_αμματοσειρά τίτλου"
+msgid "Focus model"
+msgstr "Μοντέλο εστίασης"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.h:5
-msgid "Title _alignment"
-msgstr "Στ_οίχιση τίτλου"
+msgid "New window focus"
+msgstr "Εστίαση νέου παραθύρου"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.h:6
-msgid "Click and drag the buttons to change the layout"
-msgstr "Επιλέξετε και σύρετε τα κουμπιά για να αλλάξετε τη διάταξη"
+msgid "Raise on click"
+msgstr "Ανύψωση στο κλικ"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.h:7
-msgid "Title"
-msgstr "Τίτλος"
+msgid "Raise on focus"
+msgstr "Ανύψωση κατά την εστίαση"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.h:8
-msgid "The window title cannot be removed"
-msgstr "Ο τίτλος του παραθύρου δεν μπορεί να αφαιρεθεί"
+msgid "Title _alignment"
+msgstr "Στ_οίχιση τίτλου"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.h:9
-msgid "Active"
-msgstr "Ενεργό"
+msgid "Title fon_t"
+msgstr "Γρ_αμματοσειρά τίτλου"
 
 #: ../settings-dialogs/xfwm4-dialog.glade.

[Xfce4-commits] l10n: Updated Greek (el) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/xfce-4.10
 to befc1ee0aedfee60182aacf429f4dea00176a8bb (commit)
   from ae6a1ce26a1074810dce71e2d8a821623aa67a56 (commit)

commit befc1ee0aedfee60182aacf429f4dea00176a8bb
Author: Georgios Stefanakis 
Date:   Sat Oct 6 21:43:44 2012 +0200

l10n: Updated Greek (el) translation to 100%

New status: 213 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |   72 -
 1 files changed, 38 insertions(+), 34 deletions(-)

diff --git a/po/el.po b/po/el.po
index 22d9d95..e3d93f2 100644
--- a/po/el.po
+++ b/po/el.po
@@ -4,19 +4,19 @@
 # Stavros Giannouris , 2005-2006, 2008.
 # Stathis Kamperis , 2006.
 # Efstathios Iosifidis , 2012.
-#
+# 
 msgid ""
 msgstr ""
 "Project-Id-Version: xfdesktop git\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-04-08 15:36+\n"
+"POT-Creation-Date: 2012-10-06 14:45+\n"
 "PO-Revision-Date: 2012-04-08 23:31+0300\n"
 "Last-Translator: Efstathios Iosifidis \n"
 "Language-Team: Ελληνικά, Σύγχρονα \n"
-"Language: el\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
+"Language: el\n"
 "Plural-Forms: nplurals=2; plural=(n!=1);\n"
 
 #: ../common/xfdesktop-common.c:96 ../common/xfdesktop-common.c:200
@@ -56,7 +56,7 @@ msgstr "Αφαιρούμενα μέσα"
 msgid "Cannot create backdrop list \"%s\""
 msgstr "Δεν ήταν δυνατή η δημιουργία του αρχείου λίστας \"%s\""
 
-#: ../settings/main.c:489 ../settings/main.c:862
+#: ../settings/main.c:489 ../settings/main.c:875
 msgid "Backdrop List Error"
 msgstr "Σφάλμα στη λίστα παρασκηνίων"
 
@@ -84,79 +84,79 @@ msgstr "Αν αντικαταστήσετε το αρχείο θα χαθούν
 msgid "Replace"
 msgstr "Αντικατάσταση"
 
-#: ../settings/main.c:858
+#: ../settings/main.c:871
 #, c-format
 msgid "Failed to write backdrop list to \"%s\""
 msgstr "Η εγγραφή της λίστας στο \"%s\" απέτυχε"
 
-#: ../settings/main.c:885
+#: ../settings/main.c:898
 msgid "Add Image File(s)"
 msgstr "Προσθήκη αρχείων εικόνας"
 
-#: ../settings/main.c:894
+#: ../settings/main.c:907
 msgid "Image files"
 msgstr "Αρχεία εικόνας"
 
-#: ../settings/main.c:899
+#: ../settings/main.c:912
 msgid "All files"
 msgstr "Όλα τα αρχεία"
 
-#: ../settings/main.c:1356
+#: ../settings/main.c:1376
 #, c-format
 msgid "Screen %d, Monitor %d (%s)"
 msgstr "Οθόνη %d, Monitor %d (%s)"
 
-#: ../settings/main.c:1360
+#: ../settings/main.c:1380
 #, c-format
 msgid "Screen %d, Monitor %d"
 msgstr "Οθόνη %d, Monitor %d"
 
-#: ../settings/main.c:1363
+#: ../settings/main.c:1383
 #, c-format
 msgid "Screen %d"
 msgstr "Οθόνη %d"
 
-#: ../settings/main.c:1368
+#: ../settings/main.c:1388
 #, c-format
 msgid "Monitor %d (%s)"
 msgstr "Monitor %d (%s)"
 
-#: ../settings/main.c:1372
+#: ../settings/main.c:1392
 #, c-format
 msgid "Monitor %d"
 msgstr "Monitor %d"
 
-#: ../settings/main.c:1631
+#: ../settings/main.c:1651
 msgid "Settings manager socket"
 msgstr "Υποδοχή διαχειριστή ρυθμίσεων"
 
-#: ../settings/main.c:1631
+#: ../settings/main.c:1651
 msgid "SOCKET ID"
 msgstr "SOCKET ID"
 
-#: ../settings/main.c:1632
+#: ../settings/main.c:1652
 msgid "Version information"
 msgstr "Πληροφορίες έκδοσης"
 
-#: ../settings/main.c:1649
+#: ../settings/main.c:1669
 #, c-format
 msgid "Type '%s --help' for usage."
 msgstr "Πληκτρολογήστε '%s --help' για βοήθεια σχετικά με τη χρήση του."
 
-#: ../settings/main.c:1661
+#: ../settings/main.c:1681
 msgid "The Xfce development team. All rights reserved."
 msgstr "Η ομάδα ανάπτυξης του Xfce. Όλα τα δικαιώματα διατηρούνται."
 
-#: ../settings/main.c:1662
+#: ../settings/main.c:1682
 #, c-format
 msgid "Please report bugs to <%s>."
 msgstr "Παρακαλώ αναφέρετε τυχόν σφάλματα στο <%s>."
 
-#: ../settings/main.c:1669
+#: ../settings/main.c:1689
 msgid "Desktop Settings"
 msgstr "Επιφάνεια εργασίας"
 
-#: ../settings/main.c:1671
+#: ../settings/main.c:1691
 msgid "Unable to contact settings server"
 msgstr "Δεν ήταν δυνατή η επικοινωνία με τον εξυπηρετητή ρυθμίσεων"
 
@@ -712,7 +712,7 @@ msgid "_Open in New Window"
 msgstr "Άνοιγμ_α σε νέο παράθυρο"
 
 #: ../src/xfdesktop-file-icon-manager.c:1425
-#: ../src/xfdesktop-special-file-icon.c:501 ../src/xfdesktop-volume-icon.c:683
+#: ../src/xfdesktop-special-file-icon.c:505 ../src/xfdesktop-volume-icon.c:691
 msgid "_Open"
 msgstr "_Άνοιγμα"
 
@@ -769,7 +769,7 @@ msgid "Desktop _Settings..."
 msgstr "_Ρυθμίσεις επιφάνειας εργασίας..."
 
 #: ../src/xfdesktop-file-icon-manager.c:1744
-#: ../src/xfdesktop-volume-icon.c:731
+#: ../src/xfdesktop-volume-icon.c:739
 msgid "P_roperties..."
 msgstr "_Ιδιότητες..."
 
@@ -946,7 +946,7 @@ msgstr "Εξαγωγή μονάδας"
 msgid "The device \"%s\" is being ejected. This may take some time"
 msgstr "Γίνεται εξαγωγή της μονάδας \"%s\". Αυτό μπορεί να πάρει κάποιο χρόνο"
 
-#: ../src/xfdesktop-regular-file-icon.c:567
+#: ../src/xfdesktop-regular-file-icon.c:556
 #, c-format
 msgid ""
 "Type: %s\

[Xfce4-commits] l10n: Updated Greek (el) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/xfce-4.10
 to 59130e6d6312cce75310d265ff5e2babfd11b73a (commit)
   from 829be8c993c0df73cfba8ba2aa62cec1768415b3 (commit)

commit 59130e6d6312cce75310d265ff5e2babfd11b73a
Author: Georgios Stefanakis 
Date:   Sat Oct 6 21:41:59 2012 +0200

l10n: Updated Greek (el) translation to 100%

New status: 208 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |  118 +++---
 1 files changed, 59 insertions(+), 59 deletions(-)

diff --git a/po/el.po b/po/el.po
index 75138c7..832edc9 100644
--- a/po/el.po
+++ b/po/el.po
@@ -1,23 +1,23 @@
 # Copyright (C) 2003-2006 The Xfce development team.
 # This file is distributed under the same license as the xfce4-session package.
-#
+# 
 # Stavros Giannouris , 2005, 2006, 2007.
 # Stathis Kamperis , 2006.
 # Evaggelos Balaskas , 2009.
 # Efstathios Iosifidis , 2012.
-#
+# 
 msgid ""
 msgstr ""
 "Project-Id-Version: xfce4-session git version\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-04-08 14:12+\n"
+"POT-Creation-Date: 2012-10-06 18:51+\n"
 "PO-Revision-Date: 2012-04-11 21:24+0300\n"
 "Last-Translator: Efstathios Iosifidis \n"
 "Language-Team: Ελληνικά, Σύγχρονα \n"
-"Language: el\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
+"Language: el\n"
 "Plural-Forms: nplurals=2; plural=(n!=1);\n"
 "X-Poedit-Language: Greek\n"
 "X-Poedit-SourceCharset: utf-8\n"
@@ -174,13 +174,13 @@ msgid "Type '%s --help' for usage."
 msgstr "Πληκτρολογήστε '%s --help' για βοήθεια."
 
 #: ../settings/main.c:87 ../xfce4-session/main.c:267
-#: ../xfce4-session-logout/main.c:124
+#: ../xfce4-session-logout/main.c:135
 msgid "The Xfce development team. All rights reserved."
 msgstr ""
 "Η ομάδα ανάπτυξης του xfce. Με την επιφύλαξη παντός νόμιμου δικαιώματος."
 
 #: ../settings/main.c:88 ../xfce4-session/main.c:268
-#: ../xfce4-session-logout/main.c:127
+#: ../xfce4-session-logout/main.c:138
 #, c-format
 msgid "Please report bugs to <%s>."
 msgstr "Παρακαλώ να αναφέρετε σφάλματα στο <%s>"
@@ -245,23 +245,24 @@ msgid "_Proceed"
 msgstr "_Συνέχεια"
 
 #: ../settings/session-editor.c:212
-msgid "You might need to delete some files manually in "
-msgstr "Μπορεί να χρειαστείτε να διαγράψετε μερικά αρχεία χειροκίνητα στο"
+#, c-format
+msgid "You might need to delete some files manually in \"%s\"."
+msgstr "Μπορεί να χρειαστείτε να διαγράψετε μερικά αρχεία χειροκίνητα στο 
\"%s\"."
 
-#: ../settings/session-editor.c:216
+#: ../settings/session-editor.c:215
 msgid "All Xfce cache files could not be cleared"
 msgstr "Αδυναμία εκκαθάρισης όλων των αρχείων της λανθάνουσας μνήμης του Xfce"
 
-#: ../settings/session-editor.c:250
+#: ../settings/session-editor.c:249
 #, c-format
 msgid "Are you sure you want to terminate \"%s\"?"
 msgstr "Είστε σίγουροι ότι θέλετε να τερματίσετε το \"%s\";"
 
-#: ../settings/session-editor.c:253 ../settings/session-editor.c:281
+#: ../settings/session-editor.c:252 ../settings/session-editor.c:280
 msgid "Terminate Program"
 msgstr "Τερματισμός προγράμματος"
 
-#: ../settings/session-editor.c:255
+#: ../settings/session-editor.c:254
 msgid ""
 "The application will lose any unsaved state and will not be restarted in "
 "your next session."
@@ -269,32 +270,32 @@ msgstr ""
 "Η εφαρμογή θα χάσει την μη αποθηκευμένη κατάσταση και δεν θα ξεκινήσει στην "
 "επόμενη συνεδρία σας."
 
-#: ../settings/session-editor.c:257
+#: ../settings/session-editor.c:256
 #: ../settings/xfce4-session-settings.glade.h:40
 msgid "_Quit Program"
 msgstr "Τ_ερματισμός προγράμματος"
 
-#: ../settings/session-editor.c:282
+#: ../settings/session-editor.c:281
 msgid "Unable to terminate program."
 msgstr "Αδυναμία τερματισμού προγράμματος."
 
-#: ../settings/session-editor.c:460
+#: ../settings/session-editor.c:459
 msgid "(Unknown program)"
 msgstr "(Άγνωστο πρόγραμμα)"
 
-#: ../settings/session-editor.c:680
+#: ../settings/session-editor.c:679
 msgid "Priority"
 msgstr "Προτεραιότητα"
 
-#: ../settings/session-editor.c:688
+#: ../settings/session-editor.c:687
 msgid "PID"
 msgstr "PID"
 
-#: ../settings/session-editor.c:694
+#: ../settings/session-editor.c:693
 msgid "Program"
 msgstr "Πρόγραμμα"
 
-#: ../settings/session-editor.c:719
+#: ../settings/session-editor.c:718
 msgid "Restart Style"
 msgstr "Στυλ επανεκκίνησης"
 
@@ -354,7 +355,6 @@ msgid "Failed to open %s for writing"
 msgstr "Αδυναμία ανοίγματος του '%s' για εγγραφή"
 
 #: ../settings/xfae-window.c:102
-#, fuzzy
 msgid ""
 "Below is the list of applications that will be started automatically when "
 "you login to your Xfce desktop, in addition to the applications that were "
@@ -406,7 +406,7 @@ msgstr "Αποτυχία εναλλαγής κατάστασης του αντι
 msgid "Disable binding to TCP ports"
 msgstr "Απενεργοποίηση δέσμευσης θυρών TCP"
 
-#: ../xfce4-session/main.c:77 ../xfce4-session-logout/main.c:81
+#: 

[Xfce4-commits] l10n: Updated Greek (el) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 41d556d4c4ab57430c74b6566dc2425641658db3 (commit)
   from 6955225f88ae7c66bd2ed66c28eb5225fbf30e5d (commit)

commit 41d556d4c4ab57430c74b6566dc2425641658db3
Author: Georgios Stefanakis 
Date:   Sat Oct 6 21:38:59 2012 +0200

l10n: Updated Greek (el) translation to 100%

New status: 706 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |   29 -
 1 files changed, 12 insertions(+), 17 deletions(-)

diff --git a/po/el.po b/po/el.po
index 0183272..f7ae230 100644
--- a/po/el.po
+++ b/po/el.po
@@ -650,7 +650,7 @@ msgstr "Πρ_οσπάθεια ξανά"
 
 #: ../thunar/thunar-dialogs.c:445
 msgid "Copy _Anyway"
-msgstr ""
+msgstr "_Εξαναγκασμένη αντιγραφή"
 
 #: ../thunar/thunar-dialogs.c:468
 msgid "_Cancel"
@@ -733,16 +733,15 @@ msgstr "με το ακόλουθο αρχείο;"
 msgid ""
 "The desktop file \"%s\" is in an insecure location and not marked as "
 "executable. If you do not trust this program, click Cancel."
-msgstr ""
+msgstr "Το αρχείο της επιφάνειας εργασείας \"%s\" είναι σε μη ασφάλη τοποθεσία 
και δεν είναι μαρκαρισμένο ως εκτελέσιμο.  Αν δεν εμπιστεύεστε αυτό το 
πρόγραμμα, κάντε κλίκ στην Ακύρωση."
 
 #: ../thunar/thunar-dialogs.c:777
 msgid "_Launch Anyway"
-msgstr ""
+msgstr "_Εξαναγκασμένη εκτέλεση"
 
 #: ../thunar/thunar-dialogs.c:779
-#, fuzzy
 msgid "Mark _Executable"
-msgstr "_Εκτέλεση"
+msgstr "Σημείωση ως _Εκτελέσιμο"
 
 #: ../thunar/thunar-dnd.c:72
 msgid "_Copy here"
@@ -841,9 +840,8 @@ msgstr "Η ανάλυση του αρχείου της επιφάνειας ερ
 
 #. if the .desktop file is not secure, ask user what to do
 #: ../thunar/thunar-file.c:1116
-#, fuzzy
 msgid "Untrusted application launcher"
-msgstr "Δεν επιλέχθηκε εφαρμογή"
+msgstr "Μη έμπιστος εκτελεστής αρχείου"
 
 #: ../thunar/thunar-file.c:1141
 #, c-format
@@ -853,7 +851,7 @@ msgstr "Δεν έχει οριστεί το πεδίο Exec"
 #. if the .desktop file is not secure, ask user what to do
 #: ../thunar/thunar-file.c:1150
 msgid "Untrusted link launcher"
-msgstr ""
+msgstr "Μη έμπιστος εκτελεστής συνδέσμου"
 
 #: ../thunar/thunar-file.c:1166
 #, c-format
@@ -1474,9 +1472,8 @@ msgstr ""
 "αργότερα."
 
 #: ../thunar/thunar-permissions-chooser.c:914
-#, fuzzy
 msgid "Mixed file owners"
-msgstr "Άγνωστος ιδιοκτήτης αρχείου"
+msgstr "Ανάμικτη ιδιοκτήτες αρχείου"
 
 #: ../thunar/thunar-permissions-chooser.c:914
 msgid "Unknown file owner"
@@ -1503,7 +1500,7 @@ msgstr "Εγγραφή & Ανάγνωση"
 
 #: ../thunar/thunar-permissions-chooser.c:999
 msgid "Varying (no change)"
-msgstr ""
+msgstr "Διαφορές (καμία αλλαγή)"
 
 #: ../thunar/thunar-permissions-chooser.c:1131
 msgid "Correct folder permissions automatically?"
@@ -1896,7 +1893,7 @@ msgstr "Ιδιότητες"
 
 #: ../thunar/thunar-properties-dialog.c:1207
 msgid "mixed"
-msgstr ""
+msgstr "μικτός "
 
 #: ../thunar/thunar-renamer-dialog.c:186 ../thunar/thunar-window.c:304
 msgid "_File"
@@ -2211,7 +2208,7 @@ msgstr "_Αναστροφή Επιλογής"
 
 #: ../thunar/thunar-standard-view.c:370
 msgid "Select all and only the items that are not currently selected"
-msgstr ""
+msgstr "Επιλογή όλων των αντικειμένων τα οποία δεν έχουν επιλεγεί"
 
 #: ../thunar/thunar-standard-view.c:371
 msgid "Du_plicate"
@@ -2682,10 +2679,9 @@ msgstr "Αλλαγή της ορατότητας της μπάρας κατάσ
 
 #: ../thunar/thunar-window.c:345
 msgid "_Menubar"
-msgstr ""
+msgstr "Μ_πάρα μενού"
 
 #: ../thunar/thunar-window.c:345
-#, fuzzy
 msgid "Change the visibility of this window's menubar"
 msgstr "Αλλαγή της ορατότητας της μπάρας κατάστασης του παραθύρου αυτού"
 
@@ -3047,7 +3043,7 @@ msgstr "Camelcase"
 
 #: ../plugins/thunar-sbr/thunar-sbr-enum-types.c:96
 msgid "Sentence case"
-msgstr ""
+msgstr "περίπτωση Προτάσεων"
 
 #: ../plugins/thunar-sbr/thunar-sbr-enum-types.c:102
 msgid "Insert"
@@ -3536,7 +3532,6 @@ msgid "_Other Files"
 msgstr "_Άλλα αρχεία"
 
 #: ../plugins/thunar-uca/thunar-uca-editor.c:445
-#, fuzzy
 msgid ""
 "This page lists the conditions under which the\n"
 "action will appear in the file managers context\n"
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Greek (el) translation to 98%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 6955225f88ae7c66bd2ed66c28eb5225fbf30e5d (commit)
   from 120fc032df2272a7d771a0f29ef4933d31a0cfb4 (commit)

commit 6955225f88ae7c66bd2ed66c28eb5225fbf30e5d
Author: Georgios Stefanakis 
Date:   Sat Oct 6 21:18:52 2012 +0200

l10n: Updated Greek (el) translation to 98%

New status: 692 messages complete with 5 fuzzies and 9 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |   48 
 1 files changed, 20 insertions(+), 28 deletions(-)

diff --git a/po/el.po b/po/el.po
index c804bfc..0183272 100644
--- a/po/el.po
+++ b/po/el.po
@@ -1212,7 +1212,7 @@ msgid "\"%s\" (%s) %s"
 msgstr "\"%s\" (%s) %s"
 
 #: ../thunar/thunar-list-model.c:2373
-#, fuzzy, c-format
+#, c-format
 msgid "\"%s\" %s"
 msgstr "\"%s\" (%s) %s"
 
@@ -1234,7 +1234,7 @@ msgstr "Μέγεθος εικόνας:"
 
 #. item count if there are also folders in the selection
 #: ../thunar/thunar-list-model.c:2436
-#, fuzzy, c-format
+#, c-format
 msgid "%d other item selected (%s)"
 msgid_plural "%d other items selected (%s)"
 msgstr[0] "%d επιλεγμένο αντικείμενο (%s)"
@@ -1249,18 +1249,18 @@ msgstr[0] "%d επιλεγμένο αντικείμενο (%s)"
 msgstr[1] "%d επιλεγμένα αντικείμενα (%s)"
 
 #: ../thunar/thunar-list-model.c:2457
-#, fuzzy, c-format
+#, c-format
 msgid "%d folder selected"
 msgid_plural "%d folders selected"
-msgstr[0] "%d επιλεγμένο αντικείμενο"
-msgstr[1] "%d επιλεγμένα αντικείμενα"
+msgstr[0] "%d επιλεγμένος φάκελος"
+msgstr[1] "%d επιλεγμένοι φάκελοι"
 
 #. This is marked for translation in case a localizer
 #. * needs to change ", " to something else. The comma
 #. * is between the message about the number of folders
 #. * and the number of items in the selection
 #: ../thunar/thunar-list-model.c:2476
-#, c-format, fuzzy
+#, c-format
 msgid "%s, %s"
 msgstr "%s, %s"
 
@@ -1386,23 +1386,20 @@ msgid "Owner:"
 msgstr "Ιδιοκτήτης:"
 
 #: ../thunar/thunar-permissions-chooser.c:237
-#, fuzzy
 msgid "_Access:"
-msgstr "Πρόσβαση:"
+msgstr "_Πρόσβαση:"
 
 #: ../thunar/thunar-permissions-chooser.c:261
 msgid "Gro_up:"
 msgstr "Ομά_δα:"
 
 #: ../thunar/thunar-permissions-chooser.c:280
-#, fuzzy
 msgid "Acce_ss:"
-msgstr "Πρόσβαση:"
+msgstr "Πρόσ_βαση:"
 
 #: ../thunar/thunar-permissions-chooser.c:304
-#, fuzzy
 msgid "O_thers:"
-msgstr "Άλλοι:"
+msgstr "Ά_λλοι:"
 
 #: ../thunar/thunar-permissions-chooser.c:328
 msgid "Program:"
@@ -1429,9 +1426,8 @@ msgstr ""
 "να μην μπορείτε να εργαστείτε με αρχεία μέσα σε αυτόν."
 
 #: ../thunar/thunar-permissions-chooser.c:382
-#, fuzzy
 msgid "Correct _folder permissions..."
-msgstr "Επιδιόρθωση δικαιωμάτων φακέλου..."
+msgstr "Επιδιόρθωση δι_καιωμάτων φακέλου..."
 
 #: ../thunar/thunar-permissions-chooser.c:383
 msgid "Click here to automatically fix the folder permissions."
@@ -1514,9 +1510,8 @@ msgid "Correct folder permissions automatically?"
 msgstr "Να γίνει αυτόματη επιδιόρθωση δικαιωμάτων φακέλου;"
 
 #: ../thunar/thunar-permissions-chooser.c:1133
-#, fuzzy
 msgid "Correct _folder permissions"
-msgstr "Επιδιόρθωση δικαιωμάτων φακέλου"
+msgstr "Επιδιόρθωση δ_ικαιωμάτων φακέλου"
 
 #: ../thunar/thunar-permissions-chooser.c:1135
 msgid ""
@@ -1832,9 +1827,8 @@ msgid "Kind:"
 msgstr "Είδος:"
 
 #: ../thunar/thunar-properties-dialog.c:340
-#, fuzzy
 msgid "_Open With:"
-msgstr "Άνοιγμα με:"
+msgstr "Ά_νοιγμα με:"
 
 #: ../thunar/thunar-properties-dialog.c:354
 msgid "Link Target:"
@@ -2146,15 +2140,13 @@ msgstr[1] "%u αντικείμενα, %s συνολικά"
 #. TRANSLATORS: this is shows if during the deep count size
 #. * directories were not accessible
 #: ../thunar/thunar-size-label.c:386
-#, fuzzy
 msgid "(some contents unreadable)"
-msgstr "Εμφάνιση των περιεχομένων με περισσότερη λεπτομέρεια"
+msgstr "(ορισμένα περειεχώμενα είναι μη αναγνώσιμα)"
 
 #. nothing was readable, so permission was denied
 #: ../thunar/thunar-size-label.c:397
-#, fuzzy
 msgid "Permission denied"
-msgstr "Δικαιώματα"
+msgstr "Άρνηση πρόσβασης"
 
 #: ../thunar/thunar-standard-view.c:360
 msgid "Folder Context Menu"
@@ -2215,7 +2207,7 @@ msgstr "Επιλογή όλων των αρχείων που ταιριάζου
 
 #: ../thunar/thunar-standard-view.c:370
 msgid "_Invert Selection"
-msgstr ""
+msgstr "_Αναστροφή Επιλογής"
 
 #: ../thunar/thunar-standard-view.c:370
 msgid "Select all and only the items that are not currently selected"
@@ -2385,16 +2377,16 @@ msgstr ""
 "Αδυναμία μετακίνησης του καταλόγου \"%s\". Συλλογή αρχείων για αντιγραφή..."
 
 #: ../thunar/thunar-transfer-job.c:1084
-#, fuzzy, c-format
+#, c-format
 msgid "%s of %s"
-msgstr "αντίγραφο του %s"
+msgstr "%s από %s"
 
 #: ../thunar/thunar-transfer-job.c:1104
-#, fuzzy, c-format
+#, c-format
 msgid "%lu hour remaining (%s/sec)"
 msgid_plural "%lu hours remaining (%s/sec)"
-msgstr[0] "απομένει %lu ώρα"
-msgstr[1] "απομένουν %lu ώρες"
+msgstr[0] "απομένει %lu ώρα (%s/sec)"
+msgstr[1] "απομένουν %lu ώρες (%s/sec)"
 
 #: ../thunar/thunar-transfer-job.c:1112
 #, c-format
___

[Xfce4-commits] l10n: Updated Greek (el) translation to 95%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 120fc032df2272a7d771a0f29ef4933d31a0cfb4 (commit)
   from 35fb895641e190775180a9faa9166e9c20c49add (commit)

commit 120fc032df2272a7d771a0f29ef4933d31a0cfb4
Author: Georgios Stefanakis 
Date:   Sat Oct 6 20:48:40 2012 +0200

l10n: Updated Greek (el) translation to 95%

New status: 677 messages complete with 19 fuzzies and 10 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/el.po |7 +++
 1 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/po/el.po b/po/el.po
index 844cc98..c804bfc 100644
--- a/po/el.po
+++ b/po/el.po
@@ -2397,14 +2397,14 @@ msgstr[0] "απομένει %lu ώρα"
 msgstr[1] "απομένουν %lu ώρες"
 
 #: ../thunar/thunar-transfer-job.c:1112
-#, fuzzy, c-format
+#, c-format
 msgid "%lu minute remaining (%s/sec)"
 msgid_plural "%lu minutes remaining (%s/sec)"
 msgstr[0] "απομένει %lu λεπτό"
 msgstr[1] "απομένουν %lu λεπτά"
 
 #: ../thunar/thunar-transfer-job.c:1119
-#, fuzzy, c-format
+#, c-format
 msgid "%lu second remaining (%s/sec)"
 msgid_plural "%lu seconds remaining (%s/sec)"
 msgstr[0] "απομένει %lu δευτερόλεπτο"
@@ -2880,9 +2880,8 @@ msgid "Working Directory:"
 msgstr "Τρέχων Φάκελος:"
 
 #: ../plugins/thunar-apr/thunar-apr-desktop-page.c:204
-#, fuzzy
 msgid "The working directory for the program."
-msgstr "Ο τρέχων κατάλογος πρέπει να είναι απόλυτη διαδρομή"
+msgstr "Ο τρέχων κατάλογος για το πρόγραμμα"
 
 #: ../plugins/thunar-apr/thunar-apr-desktop-page.c:219
 msgid "URL:"
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Polish (pl) translation to 100%

2012-10-06 Thread Transifex
Updating branch refs/heads/xfce-4.10
 to fad1bcea2febf5a47f7f4bb6284fcb6cba782159 (commit)
   from 41473cf00a2f6f299fde3ca1d36f16f82512600d (commit)

commit fad1bcea2febf5a47f7f4bb6284fcb6cba782159
Author: Marcin Romańczuk 
Date:   Sat Oct 6 20:07:33 2012 +0200

l10n: Updated Polish (pl) translation to 100%

New status: 213 messages complete with 0 fuzzies and 0 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/pl.po |9 -
 1 files changed, 4 insertions(+), 5 deletions(-)

diff --git a/po/pl.po b/po/pl.po
index 52e5474..8cb3326 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -2,12 +2,12 @@
 # Copyright (C) 2011 xfce4-power-manager COPYRIGHT HOLDER
 # This file is distributed under the same license as the xfce4-power-manager 
package.
 # Piotr Sokół , 2011, 2012.
-#
+# 
 msgid ""
 msgstr ""
 "Project-Id-Version: xfce-power-manager 1.0.10\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-04-29 11:33+\n"
+"POT-Creation-Date: 2012-10-06 13:06+\n"
 "PO-Revision-Date: 2012-04-29 18:56+0200\n"
 "Last-Translator: Piotr Sokół \n"
 "Language-Team: polski <>\n"
@@ -15,8 +15,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bits\n"
 "Language: pl\n"
-"Plural-Forms: nplurals=3; plural=((n==1) ? 0 : ((n%10>=2 && n%10<=4 && (n"
-"%100<10 || n%100>=20)) ? 1 : 2));\n"
+"Plural-Forms: nplurals=3; plural=((n==1) ? 0 : ((n%10>=2 && n%10<=4 && 
(n%100<10 || n%100>=20)) ? 1 : 2));\n"
 
 #: ../data/interfaces/xfpm-settings.ui.h:1
 msgid "Actions"
@@ -794,7 +793,7 @@ msgstr "Posiada akumulator"
 
 #: ../src/xfpm-main.c:157
 msgid "Has brightness panel"
-msgstr ""
+msgstr "Posiada panel jasności"
 
 #: ../src/xfpm-main.c:159
 msgid "Has power button"
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] Add completion for currently open views/ tabs

2012-10-06 Thread Christian Dywan
Updating branch refs/heads/master
 to b49aba5ed21a0ae2dae8f9abf8ceb141980bd58a (commit)
   from 536036283ae440447f61614816c1b7b794c3213b (commit)

commit b49aba5ed21a0ae2dae8f9abf8ceb141980bd58a
Author: Christian Dywan 
Date:   Sat Oct 6 19:55:18 2012 +0200

Add completion for currently open views/ tabs

 midori/midori-app.c   |   28 +++--
 midori/midori-browser.c   |   66 
 midori/midori-browser.h   |4 ++
 midori/midori-locationaction.c|   14 ++-
 midori/midori-viewcompletion.vala |   85 +
 midori/midori.vapi|2 +-
 6 files changed, 174 insertions(+), 25 deletions(-)

diff --git a/midori/midori-app.c b/midori/midori-app.c
index b3653e1..0b4fba5 100644
--- a/midori/midori-app.c
+++ b/midori/midori-app.c
@@ -543,19 +543,10 @@ midori_app_command_received (MidoriApp*   app,
 else
 {
 /* Switch to already open tab if possible */
-guint i = 0;
-GtkWidget* tab;
-gboolean found = FALSE;
-while ((tab = midori_browser_get_nth_tab (browser, 
i++)))
-if (g_str_equal (
-midori_view_get_display_uri (MIDORI_VIEW 
(tab)),
-fixed_uri))
-{
-found = TRUE;
-break;
-}
-if (found)
-midori_browser_set_current_tab (browser, tab);
+KatzeArray* items = midori_browser_get_proxy_array 
(browser);
+KatzeItem* found = katze_array_find_uri (items, 
fixed_uri);
+if (found != NULL)
+midori_browser_set_current_item (browser, found);
 else
 midori_browser_set_current_page (browser,
 midori_browser_add_uri (browser, fixed_uri));
@@ -1206,6 +1197,17 @@ midori_app_add_browser (MidoriApp* app,
 g_signal_emit (app, signals[ADD_BROWSER], 0, browser);
 }
 
+void
+midori_app_set_browsers (MidoriApp* app,
+ KatzeArray*browsers,
+ MidoriBrowser* browser)
+{
+g_return_if_fail (MIDORI_IS_APP (app));
+g_return_if_fail (KATZE_IS_ARRAY (browsers));
+katze_object_assign (app->browsers, g_object_ref (browsers));
+app->browser = browser;
+}
+
 /**
  * midori_app_create_browser:
  * @app: a #MidoriApp
diff --git a/midori/midori-browser.c b/midori/midori-browser.c
index c4c0f7a..5fd5806 100644
--- a/midori/midori-browser.c
+++ b/midori/midori-browser.c
@@ -131,6 +131,7 @@ enum
 PROP_STATUSBAR,
 PROP_STATUSBAR_TEXT,
 PROP_SETTINGS,
+PROP_PROXY_ITEMS,
 PROP_BOOKMARKS,
 PROP_TRASH,
 PROP_SEARCH_ENGINES,
@@ -2171,6 +2172,22 @@ midori_browser_class_init (MidoriBrowserClass* class)
  G_PARAM_READWRITE | 
G_PARAM_STATIC_STRINGS));
 
 /**
+* MidoriBrowser:proxy-items:
+*
+* The open views, automatically updated, for session management.
+*
+* Since: 0.4.8
+*/
+g_object_class_install_property (gobject_class,
+ PROP_PROXY_ITEMS,
+ g_param_spec_object (
+ "proxy-items",
+ "Proxy Items",
+ "The open tabs as an array",
+ KATZE_TYPE_ARRAY,
+ G_PARAM_READABLE | 
G_PARAM_STATIC_STRINGS));
+
+/**
 * MidoriBrowser:bookmarks:
 *
 * The bookmarks folder, containing all bookmarks.
@@ -3099,16 +3116,7 @@ _action_window_activate_item_alt (GtkAction* action,
   gint   button,
   MidoriBrowser* browser)
 {
-guint i;
-guint n = katze_array_get_length (browser->proxy_array);
-
-for (i = 0; i < n; i++)
-{
-GtkWidget* view;
-view = midori_browser_get_nth_tab (browser, i);
-if (midori_view_get_proxy_item (MIDORI_VIEW (view)) == item)
-midori_browser_set_current_page (browser, i);
-}
+midori_browser_set_current_item (browser, item);
 }
 
 static void
@@ -3846,6 +3854,15 @@ _action_location_submit_uri (GtkAction* action,
 gchar* new_uri;
 gint n;
 
+/* Switch to already open tab if possible */
+KatzeItem* found = katze_array_find_uri (browser->proxy_array, uri);
+if (found != NULL && !new_tab
+ && !g_str_equal (midori_browser_get_current_uri (browser), uri))
+{
+midori_browser_set_current_item (browser, found);
+return;
+}
+
 u

[Xfce4-commits] Check if the file exists before deleting vapi

2012-10-06 Thread Christian Dywan
Updating branch refs/heads/master
 to 8fa5a100e9cf9680cd8d73bc3a538d8023d7e363 (commit)
   from b49aba5ed21a0ae2dae8f9abf8ceb141980bd58a (commit)

commit 8fa5a100e9cf9680cd8d73bc3a538d8023d7e363
Author: Christian Dywan 
Date:   Sat Oct 6 19:58:33 2012 +0200

Check if the file exists before deleting vapi

 midori/wscript_build |4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)

diff --git a/midori/wscript_build b/midori/wscript_build
index cc506cc..957cc2c 100644
--- a/midori/wscript_build
+++ b/midori/wscript_build
@@ -13,7 +13,9 @@ libs = 'M UNIQUE LIBSOUP GMODULE GTHREAD LIBIDN GIO GTK 
SQLITE ' \
 
 if Options.commands['build'] or Options.commands['check']:
 blddir = str (bld.bldnode)[6:] # dir:// + absolute path
-os.remove (blddir  + '/default/midori/midori-core.vapi')
+duplicate_vapi = blddir + '/default/midori/midori-core.vapi'
+if os.path.exists (duplicate_vapi):
+  os.remove (duplicate_vapi)
 
 if progressive:
 obj = bld.new_task_gen ('cc', 'staticlib')
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Polish (pl) translation to 96%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 35086017fa0e7b87f2b51755c3e61a89a31f5527 (commit)
   from 3289b3b6f4bdce4947ababddeab2386b785c7a84 (commit)

commit 35086017fa0e7b87f2b51755c3e61a89a31f5527
Author: Marcin Romańczuk 
Date:   Sat Oct 6 19:42:25 2012 +0200

l10n: Updated Polish (pl) translation to 96%

New status: 374 messages complete with 0 fuzzies and 13 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/pl.po |   22 +++---
 1 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/po/pl.po b/po/pl.po
index b9f3f2c..664bf55 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: xfce4-panel 4.9.0\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-10-04 18:06+\n"
+"POT-Creation-Date: 2012-10-06 12:54+\n"
 "PO-Revision-Date: 2012-04-15 12:05+0200\n"
 "Last-Translator: Piotr Sokół \n"
 "Language-Team: polski <>\n"
@@ -1135,17 +1135,17 @@ msgstr "Późny wieczór"
 #: ../plugins/clock/clock-fuzzy.c:100
 #, no-c-format
 msgid "%0 o'clock"
-msgstr "godzina %0"
+msgstr "%0"
 
 #: ../plugins/clock/clock-fuzzy.c:101
 #, no-c-format
 msgid "five past %0"
-msgstr "pięć po %0"
+msgstr "pięć minut po %0"
 
 #: ../plugins/clock/clock-fuzzy.c:102
 #, no-c-format
 msgid "ten past %0"
-msgstr "dziesięć po %0"
+msgstr "dziesięć minut po %0"
 
 #: ../plugins/clock/clock-fuzzy.c:103
 #, no-c-format
@@ -1155,12 +1155,12 @@ msgstr "kwadrans po %0"
 #: ../plugins/clock/clock-fuzzy.c:104
 #, no-c-format
 msgid "twenty past %0"
-msgstr "dwadzieścia po %0"
+msgstr "dwadzieścia minut po %0"
 
 #: ../plugins/clock/clock-fuzzy.c:105
 #, no-c-format
 msgid "twenty five past %0"
-msgstr "dwadzieścia pięć po %0"
+msgstr "dwadzieścia pięć minut po %0"
 
 #: ../plugins/clock/clock-fuzzy.c:106
 #, no-c-format
@@ -1170,12 +1170,12 @@ msgstr "pół godziny po %0"
 #: ../plugins/clock/clock-fuzzy.c:107
 #, no-c-format
 msgid "twenty five to %1"
-msgstr "za dwadzieścia pięć %1"
+msgstr "za dwadzieścia pięć minut %1"
 
 #: ../plugins/clock/clock-fuzzy.c:108
 #, no-c-format
 msgid "twenty to %1"
-msgstr "za dwadzieścia %1"
+msgstr "za dwadzieścia minut %1"
 
 #: ../plugins/clock/clock-fuzzy.c:109
 #, no-c-format
@@ -1185,17 +1185,17 @@ msgstr "za kwadrans %1"
 #: ../plugins/clock/clock-fuzzy.c:110
 #, no-c-format
 msgid "ten to %1"
-msgstr "za dziesięć %1"
+msgstr "za dziesięć minut %1"
 
 #: ../plugins/clock/clock-fuzzy.c:111
 #, no-c-format
 msgid "five to %1"
-msgstr "za pięć %1"
+msgstr "za pięć minut %1"
 
 #: ../plugins/clock/clock-fuzzy.c:112
 #, no-c-format
 msgid "%1 o'clock"
-msgstr "godzina %1"
+msgstr "%1 "
 
 #. I18N: some languages have a singular form for the first hour,
 #. * other languages should just use the same strings as above
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] l10n: Updated Polish (pl) translation to 99%

2012-10-06 Thread Transifex
Updating branch refs/heads/master
 to 2ffaf33d28fdd49a55091660cbc9fd53e56afe23 (commit)
   from c046a8ddfcac00725b3144a3e176cda75a16ac81 (commit)

commit 2ffaf33d28fdd49a55091660cbc9fd53e56afe23
Author: Marcin Romańczuk 
Date:   Sat Oct 6 19:34:49 2012 +0200

l10n: Updated Polish (pl) translation to 99%

New status: 700 messages complete with 4 fuzzies and 2 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/pl.po |  167 ++---
 1 files changed, 93 insertions(+), 74 deletions(-)

diff --git a/po/pl.po b/po/pl.po
index 97683aa..96accd4 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Thunar 1.2.1\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-10-03 13:30+\n"
+"POT-Creation-Date: 2012-10-06 16:24+\n"
 "PO-Revision-Date: 2012-04-19 20:23+0100\n"
 "Last-Translator: Michał Olber \n"
 "Language-Team: polski <>\n"
@@ -137,7 +137,7 @@ msgstr "Nie udało się wykonać operacji"
 
 #. tell the user that we were unable to launch the file specified
 #: ../thunar/thunar-application.c:1100 ../thunar/thunar-application.c:1226
-#: ../thunar/thunar-launcher.c:1059 ../thunar/thunar-location-entry.c:369
+#: ../thunar/thunar-launcher.c:1055 ../thunar/thunar-location-entry.c:369
 #: ../thunar/thunar-location-entry.c:397
 #: ../thunar/thunar-shortcuts-view.c:1306 ../thunar/thunar-window.c:1601
 #, c-format
@@ -330,23 +330,23 @@ msgstr "_Domyślne dla tego typu plików"
 msgid "Failed to add new application \"%s\""
 msgstr "Nie udało się dodać programu „%s”"
 
-#: ../thunar/thunar-chooser-dialog.c:495
+#: ../thunar/thunar-chooser-dialog.c:496
 #, c-format
 msgid "Failed to execute application \"%s\""
 msgstr "Nie udało się uruchomić programu „%s”"
 
 #. append the "Remove Launcher" item
-#: ../thunar/thunar-chooser-dialog.c:567
+#: ../thunar/thunar-chooser-dialog.c:568
 msgid "_Remove Launcher"
 msgstr "_Usuń aktywator"
 
 #. update the header label
-#: ../thunar/thunar-chooser-dialog.c:650
+#: ../thunar/thunar-chooser-dialog.c:651
 #, c-format
 msgid "Open %s and other files of type \"%s\" with:"
 msgstr "Otwieranie pliku „%s” i innych plików typu „%s”, przy użyciu:"
 
-#: ../thunar/thunar-chooser-dialog.c:658
+#: ../thunar/thunar-chooser-dialog.c:659
 #, c-format
 msgid ""
 "Browse the file system to select an application to open files of type \"%s\"."
@@ -354,19 +354,19 @@ msgstr ""
 "Przegląda system plików w celu wybrania programu obsługującego pliki typu "
 "„%s”"
 
-#: ../thunar/thunar-chooser-dialog.c:664
+#: ../thunar/thunar-chooser-dialog.c:665
 #, c-format
 msgid ""
 "Change the default application for files of type \"%s\" to the selected "
 "application."
 msgstr "Zmienia domyślny program dla plików typu „%s” na wybrany"
 
-#: ../thunar/thunar-chooser-dialog.c:710
+#: ../thunar/thunar-chooser-dialog.c:711
 #, c-format
 msgid "Are you sure that you want to remove \"%s\"?"
 msgstr "Usunąć „%s”?"
 
-#: ../thunar/thunar-chooser-dialog.c:716
+#: ../thunar/thunar-chooser-dialog.c:717
 msgid ""
 "This will remove the application launcher that appears in the file context "
 "menu, but will not uninstall the application itself.\n"
@@ -380,43 +380,43 @@ msgstr ""
 "dialogowym otwieranym poleceniem „Otwórz za pomocą innego programu...”."
 
 #. display an error to the user
-#: ../thunar/thunar-chooser-dialog.c:731
+#: ../thunar/thunar-chooser-dialog.c:732
 #, c-format
 msgid "Failed to remove \"%s\""
 msgstr "Nie udało się usunąć „%s”"
 
-#: ../thunar/thunar-chooser-dialog.c:757
+#: ../thunar/thunar-chooser-dialog.c:758
 #: ../plugins/thunar-uca/thunar-uca-editor.c:473
 msgid "Select an Application"
 msgstr "Wybór pliku"
 
-#: ../thunar/thunar-chooser-dialog.c:767
+#: ../thunar/thunar-chooser-dialog.c:768
 #: ../thunar/thunar-renamer-dialog.c:1064
 #: ../plugins/thunar-uca/thunar-uca-editor.c:483
 msgid "All Files"
 msgstr "Wszystkie pliki"
 
-#: ../thunar/thunar-chooser-dialog.c:772
+#: ../thunar/thunar-chooser-dialog.c:773
 #: ../plugins/thunar-uca/thunar-uca-editor.c:488
 msgid "Executable Files"
 msgstr "Pliki wykonywalne"
 
-#: ../thunar/thunar-chooser-dialog.c:787
+#: ../thunar/thunar-chooser-dialog.c:788
 #: ../plugins/thunar-uca/thunar-uca-editor.c:503
 msgid "Perl Scripts"
 msgstr "Skrypty języka Perl"
 
-#: ../thunar/thunar-chooser-dialog.c:793
+#: ../thunar/thunar-chooser-dialog.c:794
 #: ../plugins/thunar-uca/thunar-uca-editor.c:509
 msgid "Python Scripts"
 msgstr "Skrypty języka Python"
 
-#: ../thunar/thunar-chooser-dialog.c:799
+#: ../thunar/thunar-chooser-dialog.c:800
 #: ../plugins/thunar-uca/thunar-uca-editor.c:515
 msgid "Ruby Scripts"
 msgstr "Skrypty języka Ruby"
 
-#: ../thunar/thunar-chooser-dialog.c:805
+#: ../thunar/thunar-chooser-dialog.c:806
 #: ../plugins/thunar-uca/thunar-uca-editor.c:521
 msgid "Shell Scripts"
 msgstr "Skrypty powłoki"
@@ -714,6 +714,21 @@ msgstr "następującym katalogiem?"
 msgid "ReplaceDialogPart2|with the followin

[Xfce4-commits] l10n: Updated Polish (pl) translation to 99%

2012-10-06 Thread Transifex
Updating branch refs/heads/xfce-4.10
 to 829be8c993c0df73cfba8ba2aa62cec1768415b3 (commit)
   from 7fadf4e6fac68b9f5bfe6d903dc409d47be2a779 (commit)

commit 829be8c993c0df73cfba8ba2aa62cec1768415b3
Author: Marcin Romańczuk 
Date:   Sat Oct 6 18:52:59 2012 +0200

l10n: Updated Polish (pl) translation to 99%

New status: 207 messages complete with 0 fuzzies and 1 untranslated.

Transmitted-via: Transifex (translations.xfce.org).

 po/pl.po |   52 ++--
 1 files changed, 26 insertions(+), 26 deletions(-)

diff --git a/po/pl.po b/po/pl.po
index b108704..b4d3a9f 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -11,7 +11,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: xfce4-session 4.4.0\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-04-19 14:42+\n"
+"POT-Creation-Date: 2012-10-06 13:30+\n"
 "PO-Revision-Date: 2012-04-12 10:00+0200\n"
 "Last-Translator: Piotr Sokół \n"
 "Language-Team: polski <>\n"
@@ -448,7 +448,7 @@ msgstr "Tworzy nową sesję"
 msgid "The client doesn't have any properties set yet"
 msgstr "Klient nie posiada jeszcze żadnych ustawionych właściwości"
 
-#: ../xfce4-session/xfsm-compat-gnome.c:246
+#: ../xfce4-session/xfsm-compat-gnome.c:239
 msgid "Starting The Gnome Keyring Daemon"
 msgstr "Uruchamiam demona Gnome Keyring"
 
@@ -529,7 +529,7 @@ msgstr "Nie udało się zahibernować sesji"
 #: ../xfce4-session/xfsm-manager.c:1393
 #, c-format
 msgid "Can only terminate clients when in the idle state"
-msgstr ""
+msgstr "Można jedynie zakończyć klientów w stanie bezczynności"
 
 #: ../xfce4-session/xfsm-manager.c:1956
 #, c-format
@@ -604,88 +604,88 @@ msgstr "Wybierz nazwę sesji"
 msgid "Choose a name for the new session:"
 msgstr "Wybierz nazwę dla nowej sesji:"
 
-#: ../xfce4-session/xfsm-startup.c:115
+#: ../xfce4-session/xfsm-startup.c:347
 msgid "Starting the Volume Controller"
 msgstr "Uruchamianie regulacji głośności"
 
-#: ../xfce4-session/xfsm-startup.c:117
+#: ../xfce4-session/xfsm-startup.c:349
 msgid "Starting the Panel"
 msgstr "Uruchamianie panelu"
 
-#: ../xfce4-session/xfsm-startup.c:119
+#: ../xfce4-session/xfsm-startup.c:351
 msgid "Starting the Desktop Manager"
 msgstr "Uruchamianie menedżera pulpitu"
 
-#: ../xfce4-session/xfsm-startup.c:121
+#: ../xfce4-session/xfsm-startup.c:353
 msgid "Starting the Taskbar"
 msgstr "Uruchamianie paska zadań"
 
-#: ../xfce4-session/xfsm-startup.c:123
+#: ../xfce4-session/xfsm-startup.c:355
 msgid "Starting the Window Manager"
 msgstr "Uruchamianie menedżera okien"
 
-#: ../xfce4-session/xfsm-startup.c:127
+#: ../xfce4-session/xfsm-startup.c:359
 msgid "Starting the Gnome Terminal Emulator"
 msgstr "Uruchamianie emulatora terminala Gnome"
 
-#: ../xfce4-session/xfsm-startup.c:131
+#: ../xfce4-session/xfsm-startup.c:363
 msgid "Starting the KDE Advanced Text Editor"
 msgstr "Uruchamianie edytora tekstu Kate"
 
-#: ../xfce4-session/xfsm-startup.c:133
+#: ../xfce4-session/xfsm-startup.c:365
 msgid "Starting the KDE Clipboard Manager"
 msgstr "Uruchamianie menedżera schowka KDE"
 
-#: ../xfce4-session/xfsm-startup.c:135
+#: ../xfce4-session/xfsm-startup.c:367
 msgid "Starting the KDE Mail Reader"
 msgstr "Uruchamianie programu pocztowego KDE"
 
-#: ../xfce4-session/xfsm-startup.c:137
+#: ../xfce4-session/xfsm-startup.c:369
 msgid "Starting the KDE News Reader"
 msgstr "Uruchamianie czytnika News KDE"
 
-#: ../xfce4-session/xfsm-startup.c:139
+#: ../xfce4-session/xfsm-startup.c:371
 msgid "Starting the Konqueror"
 msgstr "Uruchamianie przeglądarki Konqueror"
 
-#: ../xfce4-session/xfsm-startup.c:141
+#: ../xfce4-session/xfsm-startup.c:373
 msgid "Starting the KDE Terminal Emulator"
 msgstr "Uruchamianie emulatora terminala KDE"
 
-#: ../xfce4-session/xfsm-startup.c:145
+#: ../xfce4-session/xfsm-startup.c:377
 msgid "Starting the Beep Media Player"
 msgstr "Uruchamianie odtwarzacza mediów Beep"
 
-#: ../xfce4-session/xfsm-startup.c:147
+#: ../xfce4-session/xfsm-startup.c:379
 msgid "Starting The Gimp"
 msgstr "Uruchamianie programu Gimp"
 
-#: ../xfce4-session/xfsm-startup.c:149
+#: ../xfce4-session/xfsm-startup.c:381
 msgid "Starting the VI Improved Editor"
 msgstr "Uruchamianie edytora tekstu VIM"
 
-#: ../xfce4-session/xfsm-startup.c:151
+#: ../xfce4-session/xfsm-startup.c:383
 msgid "Starting the Session Management Proxy"
 msgstr "Uruchamianie pośrednika menadżera sesji"
 
-#: ../xfce4-session/xfsm-startup.c:153
+#: ../xfce4-session/xfsm-startup.c:385
 msgid "Starting the X-Chat IRC Client"
 msgstr "Uruchamianie klienta IRC X-Chat"
 
-#: ../xfce4-session/xfsm-startup.c:155
+#: ../xfce4-session/xfsm-startup.c:387
 msgid "Starting the X Multimedia System"
 msgstr "Uruchamianie X Multimedia System"
 
-#: ../xfce4-session/xfsm-startup.c:157
+#: ../xfce4-session/xfsm-startup.c:389
 msgid "Starting the X Terminal Emulator"
 msgstr "Uruchamianie emulatora terminala X"
 
-#: ../xfce4-session/xfsm-startup.c:159
+#: ../xfce4-session/xfsm-startup.c:391
 #, c-format
 msgid

[Xfce4-commits] Rename Disconnect to Eject on volumes.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to 08df1859847a6284cee55a54e3dab3d5bda6d42e (commit)
   from 3149473f2454f2969923719f1db77db6e7705a0a (commit)

commit 08df1859847a6284cee55a54e3dab3d5bda6d42e
Author: Nick Schermer 
Date:   Sat Oct 6 12:50:24 2012 +0200

Rename Disconnect to Eject on volumes.

 thunar/thunar-shortcuts-view.c |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/thunar/thunar-shortcuts-view.c b/thunar/thunar-shortcuts-view.c
index a26feb5..781ec92 100644
--- a/thunar/thunar-shortcuts-view.c
+++ b/thunar/thunar-shortcuts-view.c
@@ -940,7 +940,7 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView 
*view,
 gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 /* append the "Disconnect" (eject + safely remove drive) item */
-item = gtk_image_menu_item_new_with_mnemonic (_("Disconn_ect"));
+item = gtk_image_menu_item_new_with_mnemonic (_("_Eject"));
 gtk_widget_set_visible (item, (volume_mount != NULL && 
g_mount_can_eject (volume_mount)) || g_volume_can_eject (volume));
 gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK 
(thunar_shortcuts_view_disconnect), view);
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] Idle loading on startup and reload.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to 3149473f2454f2969923719f1db77db6e7705a0a (commit)
   from 22b7a8f9c59a4e493d5bae711738cd224db636ed (commit)

commit 3149473f2454f2969923719f1db77db6e7705a0a
Author: Nick Schermer 
Date:   Sat Oct 6 12:41:56 2012 +0200

Idle loading on startup and reload.

 thunar/thunar-shortcuts-model.c |  103 --
 1 files changed, 76 insertions(+), 27 deletions(-)

diff --git a/thunar/thunar-shortcuts-model.c b/thunar/thunar-shortcuts-model.c
index dbbfd3f..e16f2c9 100644
--- a/thunar/thunar-shortcuts-model.c
+++ b/thunar/thunar-shortcuts-model.c
@@ -95,7 +95,7 @@ static void   thunar_shortcuts_model_add_shortcut 
  (ThunarShort
  
ThunarShortcut*shortcut);
 static void   thunar_shortcuts_model_remove_shortcut
(ThunarShortcutsModel  *model,
  
ThunarShortcut*shortcut);
-static void   thunar_shortcuts_model_load   
(ThunarShortcutsModel  *model);
+static gboolean   thunar_shortcuts_model_load   (gpointer  
 data);
 static void   thunar_shortcuts_model_save   
(ThunarShortcutsModel  *model);
 static void   thunar_shortcuts_model_monitor
(GFileMonitor  *monitor,
  GFile 
*file,
@@ -148,10 +148,13 @@ struct _ThunarShortcutsModel
 #endif
 
   GList  *shortcuts;
+
   GList  *hidden_volumes;
   GVolumeMonitor *volume_monitor;
+  guint   volume_monitor_idle_id;
 
   GFileMonitor   *monitor;
+  guint   load_idle_id;
 };
 
 struct _ThunarShortcut
@@ -218,14 +221,17 @@ thunar_shortcuts_model_drag_source_init 
(GtkTreeDragSourceIface *iface)
 
 
 
-static void
-thunar_shortcuts_model_volumes_load (ThunarShortcutsModel *model)
+static gboolean
+thunar_shortcuts_model_volumes_load (gpointer data)
 {
+  ThunarShortcutsModel *model = THUNAR_SHORTCUTS_MODEL (data);
   ThunarShortcut *shortcut;
   GList  *volumes;
   GList  *lp;
   GList  *mounts;
 
+  GDK_THREADS_ENTER ();
+
   /* add the devices heading */
   shortcut = g_slice_new0 (ThunarShortcut);
   shortcut->group = THUNAR_SHORTCUT_GROUP_DEVICES;
@@ -262,6 +268,8 @@ thunar_shortcuts_model_volumes_load (ThunarShortcutsModel 
*model)
 }
   g_list_free (mounts);
 
+  GDK_THREADS_LEAVE ();
+
   /* monitor for changes */
   g_signal_connect (model->volume_monitor, "volume-added", G_CALLBACK 
(thunar_shortcuts_model_volume_added), model);
   g_signal_connect (model->volume_monitor, "volume-removed", G_CALLBACK 
(thunar_shortcuts_model_volume_removed), model);
@@ -269,6 +277,10 @@ thunar_shortcuts_model_volumes_load (ThunarShortcutsModel 
*model)
   g_signal_connect (model->volume_monitor, "mount-added", G_CALLBACK 
(thunar_shortcuts_model_mount_added), model);
   g_signal_connect (model->volume_monitor, "mount-removed", G_CALLBACK 
(thunar_shortcuts_model_mount_removed), model);
   g_signal_connect (model->volume_monitor, "mount-changed", G_CALLBACK 
(thunar_shortcuts_model_mount_changed), model);
+
+  model->volume_monitor_idle_id = 0;
+
+  return FALSE;
 }
 
 
@@ -295,6 +307,7 @@ thunar_shortcuts_model_shortcut_network 
(ThunarShortcutsModel *model)
 }
 
 
+
 static void
 thunar_shortcuts_model_shortcut_places (ThunarShortcutsModel *model)
 {
@@ -367,7 +380,7 @@ thunar_shortcuts_model_shortcut_places 
(ThunarShortcutsModel *model)
 g_signal_connect (model->monitor, "changed", G_CALLBACK 
(thunar_shortcuts_model_monitor), model);
 
   /* read the Gtk+ bookmarks file */
-  thunar_shortcuts_model_load (model);
+  model->load_idle_id = g_idle_add (thunar_shortcuts_model_load, model);
 
   g_object_unref (home);
   g_object_unref (bookmarks);
@@ -384,7 +397,7 @@ thunar_shortcuts_model_init (ThunarShortcutsModel *model)
 #endif
 
   /* load volumes */
-  thunar_shortcuts_model_volumes_load (model);
+  model->volume_monitor_idle_id = g_idle_add_full (G_PRIORITY_LOW, 
thunar_shortcuts_model_volumes_load, model, NULL);
 
   /* add network */
   thunar_shortcuts_model_shortcut_network (model);
@@ -402,6 +415,14 @@ thunar_shortcuts_model_finalize (GObject *object)
 
   _thunar_return_if_fail (THUNAR_IS_SHORTCUTS_MODEL (model));
 
+  /* stop bookmark load idle */
+  if (model->load_idle_id != 0)
+g_source_remove (model->load_idle_id);
+
+  /* stop volume monitor loading */
+  if (model->volume_monitor_idle_id != 0)
+g_source_remove (model->volume_monitor_idle_id);
+
   /* free all shortcuts */
   g_list_foreach (model->shortcuts, (GFunc) thunar_shortcut_free, model);
   g_list_free (model->shortcuts);
@@ -919,18 +940,21 @@ thunar_shortcuts_model_remove_shortcut 
(ThunarShortcutsModel *model,
 
 
 
-static void
-t

[Xfce4-commits] Drop the default bookmark crap.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to 22b7a8f9c59a4e493d5bae711738cd224db636ed (commit)
   from e8c56637127d5e42ff9ba32555b0ca2fbeaaeddd (commit)

commit 22b7a8f9c59a4e493d5bae711738cd224db636ed
Author: Nick Schermer 
Date:   Sat Oct 6 12:19:29 2012 +0200

Drop the default bookmark crap.

 thunar/thunar-private.h |3 -
 thunar/thunar-shortcuts-model.c |  113 ---
 thunar/thunar-window.c  |   42 +-
 3 files changed, 39 insertions(+), 119 deletions(-)

diff --git a/thunar/thunar-private.h b/thunar/thunar-private.h
index a6f8f7b..b6c58e2 100644
--- a/thunar/thunar-private.h
+++ b/thunar/thunar-private.h
@@ -88,9 +88,6 @@ typedef GUserDirectory ThunarUserDirectory;
 #define THUNAR_USER_DIRECTORY_VIDEOS   G_USER_DIRECTORY_VIDEOS
 #define THUNAR_USER_N_DIRECTORIES  (8)
 
-gchar *_thunar_get_xdg_user_dirs_locale (void);
-extern const gchar *_thunar_user_directory_names[THUNAR_USER_N_DIRECTORIES+1];
-
 G_END_DECLS;
 
 #endif /* !__THUNAR_PRIVATE_H__ */
diff --git a/thunar/thunar-shortcuts-model.c b/thunar/thunar-shortcuts-model.c
index 700a17e..dbbfd3f 100644
--- a/thunar/thunar-shortcuts-model.c
+++ b/thunar/thunar-shortcuts-model.c
@@ -47,13 +47,6 @@
 #define THUNAR_SHORTCUT(obj) ((ThunarShortcut *) (obj))
 
 
-/* I don't particularly like this here, but it's shared across a few
- * files. */
-const gchar *_thunar_user_directory_names[9] = {
-  "Desktop", "Documents", "Download", "Music", "Pictures", "Public",
-  "Templates", "Videos", NULL,
-};
-
 
 typedef struct _ThunarShortcut ThunarShortcut;
 
@@ -924,40 +917,12 @@ thunar_shortcuts_model_remove_shortcut 
(ThunarShortcutsModel *model,
 }
 }
 
-/* Reads the current xdg user dirs locale from ~/.config/xdg-user-dirs.locale
- * Notice that the result shall be freed by using g_free (). */
-gchar *
-_thunar_get_xdg_user_dirs_locale (void)
-{
-  gchar *file= NULL;
-  gchar *content = NULL;
-  gchar *locale  = NULL;
-
-  /* get the file pathname */
-  file = g_build_filename (g_get_user_config_dir (), LOCALE_FILE_NAME, NULL);
-
-  /* grab the contents and get ride of the surrounding spaces */
-  if (g_file_get_contents (file, &content, NULL, NULL))
-locale = g_strdup (g_strstrip (content));
 
-  g_free (content);
-  g_free (file);
-
-  /* if we got nothing, let's set the default locale as C */
-  if (exo_str_is_equal (locale, ""))
-{
-  g_free (locale);
-  locale = g_strdup ("C");
-}
-
-  return locale;
-}
 
 static void
 thunar_shortcuts_model_load (ThunarShortcutsModel *model)
 {
   ThunarShortcut *shortcut;
-  const gchar *user_special_dir = NULL;
   ThunarFile  *file;
   GFile   *file_path;
   GFile   *home;
@@ -965,7 +930,6 @@ thunar_shortcuts_model_load (ThunarShortcutsModel *model)
   gcharline[2048];
   gchar   *name;
   FILE*fp;
-  gint i;
   gint sort_id;
 
   home = thunar_g_file_new_for_home ();
@@ -1045,83 +1009,6 @@ thunar_shortcuts_model_load (ThunarShortcutsModel *model)
   /* clean up */
   fclose (fp);
 }
-  else
-{
-  /* ~/.gtk-bookmarks wasn't there or it was unreadable.
-   * here we recreate it with some useful xdg user special dirs */
-  gchar *old_locale = NULL;
-  gchar *locale  = NULL;
-
-  bindtextdomain (XDG_USER_DIRS_PACKAGE, PACKAGE_LOCALE_DIR);
-#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-  bind_textdomain_codeset (XDG_USER_DIRS_PACKAGE, "UTF-8");
-#endif /* HAVE_BIND_TEXTDOMAIN_CODESET */
-
-  /* save the old locale */
-  old_locale = g_strdup(setlocale (LC_MESSAGES, NULL));
-
-  /* set the new locale */
-  locale = _thunar_get_xdg_user_dirs_locale ();
-  setlocale (LC_MESSAGES, locale);
-  g_free (locale);
-
-  for (i = G_USER_DIRECTORY_DESKTOP;
-   i < G_USER_N_DIRECTORIES && _thunar_user_directory_names[i] != NULL;
-   ++i)
-{
-  /* let's ignore some directories we don't want in the side pane */
-  if (i == G_USER_DIRECTORY_DESKTOP
-  || i == G_USER_DIRECTORY_PUBLIC_SHARE
-  || i == G_USER_DIRECTORY_TEMPLATES)
-{
-  continue;
-}
-
-  user_special_dir = g_get_user_special_dir (i);
-
-  if (G_UNLIKELY (user_special_dir == NULL))
-continue;
-
-  file_path = g_file_new_for_path (user_special_dir);
-  if (G_UNLIKELY (g_file_equal (file_path, home)))
-{
-  g_object_unref (file_path);
-  continue;
-}
-
-  /* try to open the file corresponding to the uri */
-  file = thunar_file_get (file_path, NULL);
-  g_object_unref (file_path);
-
-  /* TODO invisible item? */
-  if (G_UNLIKELY (file == NULL))
-continue;
-
-  /* make sure the file refers to a directory */
-  if (G_UNLIKELY (!thunar_file_is_dir

[Xfce4-commits] Use info from ThunarFiles for home/desktop/trash.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to e8c56637127d5e42ff9ba32555b0ca2fbeaaeddd (commit)
   from db38495d95649cbc31bbba619a2f9377dbdd86bf (commit)

commit e8c56637127d5e42ff9ba32555b0ca2fbeaaeddd
Author: Nick Schermer 
Date:   Sat Oct 6 12:16:06 2012 +0200

Use info from ThunarFiles for home/desktop/trash.

 thunar/thunar-shortcuts-model.c |4 
 1 files changed, 0 insertions(+), 4 deletions(-)

diff --git a/thunar/thunar-shortcuts-model.c b/thunar/thunar-shortcuts-model.c
index 255ca6e..700a17e 100644
--- a/thunar/thunar-shortcuts-model.c
+++ b/thunar/thunar-shortcuts-model.c
@@ -330,7 +330,6 @@ thunar_shortcuts_model_shortcut_places 
(ThunarShortcutsModel *model)
   shortcut->group = THUNAR_SHORTCUT_GROUP_PLACES;
   shortcut->file = file;
   shortcut->sort_id = 0;
-  shortcut->gicon = g_themed_icon_new ("user-home");
   thunar_shortcuts_model_add_shortcut (model, shortcut);
 }
 
@@ -344,7 +343,6 @@ thunar_shortcuts_model_shortcut_places 
(ThunarShortcutsModel *model)
   shortcut = g_slice_new0 (ThunarShortcut);
   shortcut->group = THUNAR_SHORTCUT_GROUP_PLACES;
   shortcut->file = file;
-  shortcut->gicon = g_themed_icon_new ("user-desktop");
   shortcut->sort_id =  1;
   thunar_shortcuts_model_add_shortcut (model, shortcut);
 }
@@ -363,8 +361,6 @@ thunar_shortcuts_model_shortcut_places 
(ThunarShortcutsModel *model)
   shortcut = g_slice_new0 (ThunarShortcut);
   shortcut->group = THUNAR_SHORTCUT_GROUP_TRASH;
   shortcut->file = file;
-  shortcut->gicon = g_themed_icon_new ("user-trash");
-  shortcut->name = g_strdup (_("Trash"));
   thunar_shortcuts_model_add_shortcut (model, shortcut);
 }
 }
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits


[Xfce4-commits] Remove unneeded lines.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to db38495d95649cbc31bbba619a2f9377dbdd86bf (commit)
   from 437ac8fa86b1c41ea5ea9bab92aa74498f584d7c (commit)

commit db38495d95649cbc31bbba619a2f9377dbdd86bf
Author: Nick Schermer 
Date:   Sat Oct 6 10:15:45 2012 +0200

Remove unneeded lines.

 thunar/thunar-shortcuts-view.c |2 --
 1 files changed, 0 insertions(+), 2 deletions(-)

diff --git a/thunar/thunar-shortcuts-view.c b/thunar/thunar-shortcuts-view.c
index 11f76c4..a26feb5 100644
--- a/thunar/thunar-shortcuts-view.c
+++ b/thunar/thunar-shortcuts-view.c
@@ -322,7 +322,6 @@ thunar_shortcuts_view_init (ThunarShortcutsView *view)
   renderer = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
"ellipsize-set", TRUE,
"ellipsize", PANGO_ELLIPSIZE_END,
-   "width-chars", g_utf8_strlen (_("File System"), -1),
NULL);
   g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK 
(thunar_shortcuts_view_renamed), view);
   gtk_tree_view_column_pack_start (column, renderer, TRUE);
@@ -337,7 +336,6 @@ thunar_shortcuts_view_init (ThunarShortcutsView *view)
   gtk_tree_view_column_pack_start (column, renderer, FALSE);
   gtk_tree_view_column_set_attributes (column, renderer,
"visible", 
THUNAR_SHORTCUTS_MODEL_COLUMN_CAN_EJECT,
-   "visible", 
THUNAR_SHORTCUTS_MODEL_COLUMN_NOT_HEADER,
NULL);
 
 
___
Xfce4-commits mailing list
Xfce4-commits@xfce.org
https://mail.xfce.org/mailman/listinfo/xfce4-commits
diff --git a/thunar/thunar-shortcuts-icon-renderer.c 
b/thunar/thunar-shortcuts-icon-renderer.c
index a31f553..3797140 100644
--- a/thunar/thunar-shortcuts-icon-renderer.c
+++ b/thunar/thunar-shortcuts-icon-renderer.c
@@ -28,6 +28,7 @@
 #include 
 #include 
 #include 
+#include 
 
 
 
@@ -36,7 +37,7 @@ enum
 {
   PROP_0,
   PROP_VOLUME,
-  PROP_MOUNT,
+  PROP_DEVICE,
   PROP_GICON,
 };
 
@@ -71,7 +72,7 @@ struct _ThunarShortcutsIconRenderer
   ThunarIconRenderer __parent__;
 
   GVolume   *volume;
-  GMount*mount;
+  ThunarDevice  *device;
   GIcon *gicon;
 };
 
@@ -108,15 +109,15 @@ thunar_shortcuts_icon_renderer_class_init 
(ThunarShortcutsIconRendererClass *kla
 EXO_PARAM_READWRITE));
 
   /**
-   * ThunarShortcutsIconRenderer:mount:
+   * ThunarShortcutsIconRenderer:device:
*
    * The #GMount for which to render an icon or %NULL to fallback
* to the default icon renderering (see #ThunarIconRenderer).
**/
   g_object_class_install_property (gobject_class,
-   PROP_MOUNT,
-   g_param_spec_object ("mount", "mount", 
"mount",
-G_TYPE_MOUNT,
+   PROP_DEVICE,
+   g_param_spec_object ("device", "device", 
"device",
+THUNAR_TYPE_DEVICE,
 EXO_PARAM_READWRITE));
 
   /**
@@ -152,8 +153,8 @@ thunar_shortcuts_icon_renderer_finalize (GObject *object)
   if (G_UNLIKELY (renderer->volume != NULL))
 g_object_unref (renderer->volume);
 
-  if (G_UNLIKELY (renderer->mount != NULL))
-g_object_unref (renderer->mount);
+  if (G_UNLIKELY (renderer->device != NULL))
+g_object_unref (renderer->device);
 
   if (G_UNLIKELY (renderer->gicon != NULL))
 g_object_unref (renderer->gicon);
@@ -177,8 +178,8 @@ thunar_shortcuts_icon_renderer_get_property (GObject
*object,
   g_value_set_object (value, renderer->volume);
   break;
 
-case PROP_MOUNT:
-  g_value_set_object (value, renderer->mount);
+case PROP_DEVICE:
+  g_value_set_obje
@@ -108,15 +109,15 @@ thunar_shortcuts_icon_renderer_class_init 
*
-   * The #GMount for which to render an icon or %NULL to fallback
+   * The #ThunarDevice for which to render an icon or %NULL to fallback
* to the default icon renderering (see #ThunarIconRenderer).
**/

[Xfce4-commits] Add ThunarDevice and ThunarDeviceMonitor.

2012-10-06 Thread Nick Schermer
Updating branch refs/heads/nick/new-shortcuts-pane-model
 to a0f743d61115cf90a48d6273f9b569e2b7dad63f (commit)
   from e96bd793fbed41667d3fd8bbfc2ed231af71559d (commit)

commit a0f743d61115cf90a48d6273f9b569e2b7dad63f
Author: Nick Schermer 
Date:   Sun Oct 7 00:10:30 2012 +0200

Add ThunarDevice and ThunarDeviceMonitor.

This is an shell around GVolumeMonitor and GVolume/GMount and
possibly in the future GDrive. The idea is that the models
and views don't need to know what type they handle.

If a volume/drive/mount needs to be visible to the user, it is
added with device-added, if something changed, device-removed is
triggered and when the device need to be invisible or is removed
device-removed is called.

It also takes care of the mount/unmount/eject feature, independent of
the type.

 thunar/Makefile.am |4 +
 thunar/thunar-device-monitor.c |  639 
 thunar/thunar-device-monitor.h |   44 +++
 thunar/thunar-device.c |  711 
 thunar/thunar-device.h |   88 +
 5 files changed, 1486 insertions(+), 0 deletions(-)
